/* GXmlHashMapAttr.c generated by valac 0.44.3, the Vala compiler
 * generated from GXmlHashMapAttr.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 0; tab-width: 2 -*- */
/* GXmlHashMapAttr.vala
 *
 * Copyright (C) 2015  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <gee.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <libxml/tree.h>
#include <glib/gi18n-lib.h>
#include <libxml/parser.h>

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;
typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())
typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())
typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;
typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_PARSER (gxml_parser_get_type ())
#define GXML_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_PARSER, GXmlParser))
#define GXML_IS_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_PARSER))
#define GXML_PARSER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_PARSER, GXmlParserIface))

typedef struct _GXmlParser GXmlParser;
typedef struct _GXmlParserIface GXmlParserIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;
typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_GHASH_MAP_ATTR (gxml_ghash_map_attr_get_type ())
#define GXML_GHASH_MAP_ATTR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GHASH_MAP_ATTR, GXmlGHashMapAttr))
#define GXML_GHASH_MAP_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GHASH_MAP_ATTR, GXmlGHashMapAttrClass))
#define GXML_IS_GHASH_MAP_ATTR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GHASH_MAP_ATTR))
#define GXML_IS_GHASH_MAP_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GHASH_MAP_ATTR))
#define GXML_GHASH_MAP_ATTR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GHASH_MAP_ATTR, GXmlGHashMapAttrClass))

typedef struct _GXmlGHashMapAttr GXmlGHashMapAttr;
typedef struct _GXmlGHashMapAttrClass GXmlGHashMapAttrClass;
typedef struct _GXmlGHashMapAttrPrivate GXmlGHashMapAttrPrivate;

#define GXML_TYPE_GNODE (gxml_gnode_get_type ())
#define GXML_GNODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNODE, GXmlGNode))
#define GXML_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNODE, GXmlGNodeClass))
#define GXML_IS_GNODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNODE))
#define GXML_IS_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNODE))
#define GXML_GNODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNODE, GXmlGNodeClass))

typedef struct _GXmlGNode GXmlGNode;
typedef struct _GXmlGNodeClass GXmlGNodeClass;

#define GXML_TYPE_GDOCUMENT (gxml_gdocument_get_type ())
#define GXML_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocument))
#define GXML_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))
#define GXML_IS_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOCUMENT))
#define GXML_IS_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOCUMENT))
#define GXML_GDOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))

typedef struct _GXmlGDocument GXmlGDocument;
typedef struct _GXmlGDocumentClass GXmlGDocumentClass;
enum  {
	GXML_GHASH_MAP_ATTR_0_PROPERTY,
	GXML_GHASH_MAP_ATTR_ENTRIES_PROPERTY,
	GXML_GHASH_MAP_ATTR_KEYS_PROPERTY,
	GXML_GHASH_MAP_ATTR_READ_ONLY_PROPERTY,
	GXML_GHASH_MAP_ATTR_SIZE_PROPERTY,
	GXML_GHASH_MAP_ATTR_VALUES_PROPERTY,
	GXML_GHASH_MAP_ATTR_LENGTH_PROPERTY,
	GXML_GHASH_MAP_ATTR_NUM_PROPERTIES
};
static GParamSpec* gxml_ghash_map_attr_properties[GXML_GHASH_MAP_ATTR_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GXML_TYPE_GATTRIBUTE (gxml_gattribute_get_type ())
#define GXML_GATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GATTRIBUTE, GXmlGAttribute))
#define GXML_GATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GATTRIBUTE, GXmlGAttributeClass))
#define GXML_IS_GATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GATTRIBUTE))
#define GXML_IS_GATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GATTRIBUTE))
#define GXML_GATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GATTRIBUTE, GXmlGAttributeClass))

typedef struct _GXmlGAttribute GXmlGAttribute;
typedef struct _GXmlGAttributeClass GXmlGAttributeClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define GXML_GHASH_MAP_ATTR_TYPE_ITERATOR (gxml_ghash_map_attr_iterator_get_type ())
#define GXML_GHASH_MAP_ATTR_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_GHASH_MAP_ATTR_TYPE_ITERATOR, GXmlGHashMapAttrIterator))
#define GXML_GHASH_MAP_ATTR_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_GHASH_MAP_ATTR_TYPE_ITERATOR, GXmlGHashMapAttrIteratorClass))
#define GXML_GHASH_MAP_ATTR_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_GHASH_MAP_ATTR_TYPE_ITERATOR))
#define GXML_GHASH_MAP_ATTR_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_GHASH_MAP_ATTR_TYPE_ITERATOR))
#define GXML_GHASH_MAP_ATTR_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_GHASH_MAP_ATTR_TYPE_ITERATOR, GXmlGHashMapAttrIteratorClass))

typedef struct _GXmlGHashMapAttrIterator GXmlGHashMapAttrIterator;
typedef struct _GXmlGHashMapAttrIteratorClass GXmlGHashMapAttrIteratorClass;

#define GXML_TYPE_DOM_ATTR (gxml_dom_attr_get_type ())
#define GXML_DOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ATTR, GXmlDomAttr))
#define GXML_IS_DOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ATTR))
#define GXML_DOM_ATTR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ATTR, GXmlDomAttrIface))

typedef struct _GXmlDomAttr GXmlDomAttr;
typedef struct _GXmlDomAttrIface GXmlDomAttrIface;

#define GXML_GHASH_MAP_ATTR_TYPE_ENTRY (gxml_ghash_map_attr_entry_get_type ())
#define GXML_GHASH_MAP_ATTR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_GHASH_MAP_ATTR_TYPE_ENTRY, GXmlGHashMapAttrEntry))
#define GXML_GHASH_MAP_ATTR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_GHASH_MAP_ATTR_TYPE_ENTRY, GXmlGHashMapAttrEntryClass))
#define GXML_GHASH_MAP_ATTR_IS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_GHASH_MAP_ATTR_TYPE_ENTRY))
#define GXML_GHASH_MAP_ATTR_IS_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_GHASH_MAP_ATTR_TYPE_ENTRY))
#define GXML_GHASH_MAP_ATTR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_GHASH_MAP_ATTR_TYPE_ENTRY, GXmlGHashMapAttrEntryClass))

typedef struct _GXmlGHashMapAttrEntry GXmlGHashMapAttrEntry;
typedef struct _GXmlGHashMapAttrEntryClass GXmlGHashMapAttrEntryClass;
typedef struct _GXmlGHashMapAttrEntryPrivate GXmlGHashMapAttrEntryPrivate;
enum  {
	GXML_GHASH_MAP_ATTR_ENTRY_0_PROPERTY,
	GXML_GHASH_MAP_ATTR_ENTRY_KEY_PROPERTY,
	GXML_GHASH_MAP_ATTR_ENTRY_READ_ONLY_PROPERTY,
	GXML_GHASH_MAP_ATTR_ENTRY_VALUE_PROPERTY,
	GXML_GHASH_MAP_ATTR_ENTRY_NUM_PROPERTIES
};
static GParamSpec* gxml_ghash_map_attr_entry_properties[GXML_GHASH_MAP_ATTR_ENTRY_NUM_PROPERTIES];
typedef struct _GXmlGHashMapAttrIteratorPrivate GXmlGHashMapAttrIteratorPrivate;
enum  {
	GXML_GHASH_MAP_ATTR_ITERATOR_0_PROPERTY,
	GXML_GHASH_MAP_ATTR_ITERATOR_MUTABLE_PROPERTY,
	GXML_GHASH_MAP_ATTR_ITERATOR_READ_ONLY_PROPERTY,
	GXML_GHASH_MAP_ATTR_ITERATOR_VALID_PROPERTY,
	GXML_GHASH_MAP_ATTR_ITERATOR_NUM_PROPERTIES
};
static GParamSpec* gxml_ghash_map_attr_iterator_properties[GXML_GHASH_MAP_ATTR_ITERATOR_NUM_PROPERTIES];

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, gint* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, gint tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, gint tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gboolean (*matches) (GXmlDomElement* self, const gchar* selectors, GError** error);
	void (*read_from_uri) (GXmlDomElement* self, const gchar* uri, GError** error);
	void (*read_from_uri_async) (GXmlDomElement* self, const gchar* uri, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_uri_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_file) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GError** error);
	void (*read_from_file_async) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_file_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_stream) (GXmlDomElement* self, GInputStream* istream, GCancellable* cancellable, GError** error);
	void (*read_from_stream_async) (GXmlDomElement* self, GInputStream* istream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_string) (GXmlDomElement* self, const gchar* str, GCancellable* cancellable, GError** error);
	void (*read_from_string_async) (GXmlDomElement* self, const gchar* str, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_string_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlDomElement* self, GCancellable* cancellable, GError** error);
	void (*write_string_async) (GXmlDomElement* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*write_file) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GError** error);
	void (*write_file_async) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlDomElement* self, GOutputStream* stream, GError** error);
	void (*write_stream_async) (GXmlDomElement* self, GOutputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlDomElement* self, GError** error);
	void (*create_stream_async) (GXmlDomElement* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parent_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*first_child) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*last_child) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previous_sibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*next_sibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previous_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*next_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlParserIface {
	GTypeInterface parent_iface;
	void (*write_file) (GXmlParser* self, GFile* file, GError** error);
	void (*write_file_async) (GXmlParser* self, GFile* file, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlParser* self, GError** error);
	void (*write_string_async) (GXmlParser* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlParser* self, GOutputStream* stream, GError** error);
	void (*write_stream_async) (GXmlParser* self, GOutputStream* stream, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_file) (GXmlParser* self, GFile* file, GError** error);
	void (*read_file_async) (GXmlParser* self, GFile* file, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_file_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_stream) (GXmlParser* self, GInputStream* stream, GError** error);
	void (*read_stream_async) (GXmlParser* self, GInputStream* stream, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_string) (GXmlParser* self, const gchar* str, GError** error);
	void (*read_string_async) (GXmlParser* self, const gchar* str, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_string_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlParser* self, GError** error);
	void (*create_stream_async) (GXmlParser* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_child_nodes) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	void (*read_child_nodes_async) (GXmlParser* self, GXmlDomNode* parent, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_child_nodes_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	gboolean (*read_child_node) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	gboolean (*read_child_element) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	gboolean (*read_element_property) (GXmlParser* self, GXmlDomNode* parent, GXmlDomNode* * element, GError** error);
	gboolean (*add_element_collection) (GXmlParser* self, GXmlDomNode* parent, GXmlDomNode* * element, GError** error);
	void (*read_child_nodes_stream) (GXmlParser* self, GInputStream* istream, GError** error);
	void (*read_child_nodes_string) (GXmlParser* self, const gchar* str, GError** error);
	gchar* (*read_unparsed) (GXmlParser* self, GError** error);
	gboolean (*move_next_node) (GXmlParser* self, GError** error);
	gboolean (*current_is_empty_element) (GXmlParser* self);
	gboolean (*current_is_element) (GXmlParser* self);
	gboolean (*current_is_document) (GXmlParser* self);
	gchar* (*current_node_name) (GXmlParser* self);
	GXmlDomElement* (*create_element) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	void (*read_element) (GXmlParser* self, GXmlDomElement* element, GError** error);
	gboolean (*get_backup) (GXmlParser* self);
	void (*set_backup) (GXmlParser* self, gboolean value);
	gboolean (*get_indent) (GXmlParser* self);
	void (*set_indent) (GXmlParser* self, gboolean value);
	GCancellable* (*get_cancellable) (GXmlParser* self);
	void (*set_cancellable) (GXmlParser* self, GCancellable* value);
	GXmlDomNode* (*get_node) (GXmlParser* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	void (*write_file) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GError** error);
	void (*write_file_async) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlDomDocument* self, GOutputStream* stream, GCancellable* cancellable, GError** error);
	void (*write_stream_async) (GXmlDomDocument* self, GOutputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlDomDocument* self, GError** error);
	void (*create_stream_async) (GXmlDomDocument* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlDomDocument* self, GCancellable* cancellable, GError** error);
	void (*write_string_async) (GXmlDomDocument* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_file) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GError** error);
	void (*read_from_file_async) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_file_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_string) (GXmlDomDocument* self, const gchar* str, GCancellable* cancellable, GError** error);
	void (*read_from_string_async) (GXmlDomDocument* self, const gchar* str, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_string_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_stream) (GXmlDomDocument* self, GInputStream* stream, GCancellable* cancellable, GError** error);
	void (*read_from_stream_async) (GXmlDomDocument* self, GInputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	GXmlParser* (*get_xml_parser) (GXmlDomDocument* self);
	void (*set_xml_parser) (GXmlDomDocument* self, GXmlParser* parser);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlGHashMapAttr {
	GeeAbstractMap parent_instance;
	GXmlGHashMapAttrPrivate * priv;
};

struct _GXmlGHashMapAttrClass {
	GeeAbstractMapClass parent_class;
};

struct _GXmlGHashMapAttrPrivate {
	GXmlGDocument* _doc;
	xmlNode* _node;
};

typedef enum  {
	GXML_DOM_ERROR_INDEX_SIZE_ERROR = 1,
	GXML_DOM_ERROR_DOMSTRING_SIZE_ERROR,
	GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR,
	GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR,
	GXML_DOM_ERROR_INVALID_CHARACTER_ERROR,
	GXML_DOM_ERROR_NO_DATA_ALLOWED_ERROR,
	GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR,
	GXML_DOM_ERROR_NOT_FOUND_ERROR,
	GXML_DOM_ERROR_NOT_SUPPORTED_ERROR,
	GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR,
	GXML_DOM_ERROR_INVALID_STATE_ERROR,
	GXML_DOM_ERROR_SYNTAX_ERROR,
	GXML_DOM_ERROR_INVALID_MODIFICATION_ERROR,
	GXML_DOM_ERROR_NAMESPACE_ERROR,
	GXML_DOM_ERROR_INVALID_ACCESS_ERROR,
	GXML_DOM_ERROR_VALIDATION_ERROR,
	GXML_DOM_ERROR_TYPE_MISMATCH_ERROR,
	GXML_DOM_ERROR_SECURITY_ERROR,
	GXML_DOM_ERROR_NETWORK_ERROR,
	GXML_DOM_ERROR_ABORT_ERROR,
	GXML_DOM_ERROR_URL_MISMATCH_ERROR,
	GXML_DOM_ERROR_QUOTA_EXCEEDED_ERROR,
	GXML_DOM_ERROR_TIME_OUT_ERROR,
	GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR,
	GXML_DOM_ERROR_DATA_CLONE_ERROR
} GXmlDomError;
#define GXML_DOM_ERROR gxml_dom_error_quark ()
struct _GXmlDomAttrIface {
	GTypeInterface parent_iface;
	gchar* (*get_namespace_uri) (GXmlDomAttr* self);
	gchar* (*get_prefix) (GXmlDomAttr* self);
	gchar* (*get_local_name) (GXmlDomAttr* self);
	gchar* (*get_name) (GXmlDomAttr* self);
	gchar* (*get_value) (GXmlDomAttr* self);
	void (*set_value) (GXmlDomAttr* self, const gchar* value);
	gboolean (*get_specified) (GXmlDomAttr* self);
};

struct _GXmlGHashMapAttrEntry {
	GeeMapEntry parent_instance;
	GXmlGHashMapAttrEntryPrivate * priv;
};

struct _GXmlGHashMapAttrEntryClass {
	GeeMapEntryClass parent_class;
};

struct _GXmlGHashMapAttrEntryPrivate {
	GXmlGDocument* _doc;
	xmlAttr* _attr;
	GXmlGAttribute* oattr;
};

struct _GXmlGHashMapAttrIterator {
	GObject parent_instance;
	GXmlGHashMapAttrIteratorPrivate * priv;
};

struct _GXmlGHashMapAttrIteratorClass {
	GObjectClass parent_class;
};

struct _GXmlGHashMapAttrIteratorPrivate {
	GXmlGDocument* _doc;
	xmlNode* _node;
	xmlAttr* _current;
};

static gint GXmlGHashMapAttr_private_offset;
static gpointer gxml_ghash_map_attr_parent_class = NULL;
static gint GXmlGHashMapAttrEntry_private_offset;
static gpointer gxml_ghash_map_attr_entry_parent_class = NULL;
static gint GXmlGHashMapAttrIterator_private_offset;
static gpointer gxml_ghash_map_attr_iterator_parent_class = NULL;
static GeeMapIteratorIface * gxml_ghash_map_attr_iterator_gee_map_iterator_parent_iface = NULL;
static GXmlDomNamedNodeMapIface * gxml_ghash_map_attr_gxml_dom_named_node_map_parent_iface = NULL;

GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_parser_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_ghash_map_attr_get_type (void) G_GNUC_CONST;
GType gxml_gnode_get_type (void) G_GNUC_CONST;
GType gxml_gdocument_get_type (void) G_GNUC_CONST;
GXmlGHashMapAttr* gxml_ghash_map_attr_new (GXmlGDocument* doc,
                                           xmlNode* node);
GXmlGHashMapAttr* gxml_ghash_map_attr_construct (GType object_type,
                                                 GXmlGDocument* doc,
                                                 xmlNode* node);
static void gxml_ghash_map_attr_real_clear (GeeAbstractMap* base);
static GXmlGNode* gxml_ghash_map_attr_real_get (GeeAbstractMap* base,
                                         const gchar* key);
GXmlGAttribute* gxml_gattribute_new (GXmlGDocument* doc,
                                     xmlAttr* node);
GXmlGAttribute* gxml_gattribute_construct (GType object_type,
                                           GXmlGDocument* doc,
                                           xmlAttr* node);
GType gxml_gattribute_get_type (void) G_GNUC_CONST;
static gboolean gxml_ghash_map_attr_real_has (GeeAbstractMap* base,
                                       const gchar* key,
                                       GXmlGNode* value);
static gboolean gxml_ghash_map_attr_real_has_key (GeeAbstractMap* base,
                                           const gchar* key);
static GeeMapIterator* gxml_ghash_map_attr_real_map_iterator (GeeAbstractMap* base);
GXmlGHashMapAttrIterator* gxml_ghash_map_attr_iterator_new (GXmlGDocument* doc,
                                                            xmlNode* node);
GXmlGHashMapAttrIterator* gxml_ghash_map_attr_iterator_construct (GType object_type,
                                                                  GXmlGDocument* doc,
                                                                  xmlNode* node);
GType gxml_ghash_map_attr_iterator_get_type (void) G_GNUC_CONST;
static void gxml_ghash_map_attr_real_set (GeeAbstractMap* base,
                                   const gchar* key,
                                   GXmlGNode* value);
gchar* gxml_gnode_get_value (GXmlGNode* self);
static gboolean gxml_ghash_map_attr_real_unset (GeeAbstractMap* base,
                                         const gchar* key,
                                         GXmlGNode* * value);
static GXmlDomNode* gxml_ghash_map_attr_real_get_named_item (GXmlDomNamedNodeMap* base,
                                                      const gchar* name);
static GXmlDomNode* gxml_ghash_map_attr_real_item (GXmlDomNamedNodeMap* base,
                                            gint index);
static GXmlDomNode* gxml_ghash_map_attr_real_set_named_item (GXmlDomNamedNodeMap* base,
                                                      GXmlDomNode* node,
                                                      GError** error);
GXmlDomNode* gxml_dom_node_get_parent_node (GXmlDomNode* self);
GXmlDomDocument* gxml_dom_node_get_owner_document (GXmlDomNode* self);
GQuark gxml_dom_error_quark (void);
GType gxml_dom_attr_get_type (void) G_GNUC_CONST;
void gxml_dom_element_set_attribute (GXmlDomElement* self,
                                     const gchar* name,
                                     const gchar* value,
                                     GError** error);
gchar* gxml_dom_node_get_node_name (GXmlDomNode* self);
gchar* gxml_dom_node_get_node_value (GXmlDomNode* self);
static GXmlDomNode* gxml_ghash_map_attr_real_remove_named_item (GXmlDomNamedNodeMap* base,
                                                         const gchar* name,
                                                         GError** error);
GXmlDomNamedNodeMap* gxml_dom_element_get_attributes (GXmlDomElement* self);
GXmlDomNode* gxml_dom_named_node_map_get_named_item (GXmlDomNamedNodeMap* self,
                                                     const gchar* name);
xmlNode* gxml_gnode_get_internal_node (GXmlGNode* self);
static GXmlDomNode* gxml_ghash_map_attr_real_get_named_item_ns (GXmlDomNamedNodeMap* base,
                                                         const gchar* namespace_uri,
                                                         const gchar* local_name,
                                                         GError** error);
gchar* gxml_dom_element_get_namespace_uri (GXmlDomElement* self);
gchar* gxml_dom_attr_get_namespace_uri (GXmlDomAttr* self);
static GXmlDomNode* gxml_ghash_map_attr_real_set_named_item_ns (GXmlDomNamedNodeMap* base,
                                                         GXmlDomNode* node,
                                                         GError** error);
void gxml_dom_element_set_attribute_ns (GXmlDomElement* self,
                                        const gchar* namespace,
                                        const gchar* name,
                                        const gchar* value,
                                        GError** error);
gchar* gxml_dom_attr_get_prefix (GXmlDomAttr* self);
GXmlDomNode* gxml_dom_named_node_map_get_named_item_ns (GXmlDomNamedNodeMap* self,
                                                        const gchar* namespace_uri,
                                                        const gchar* local_name,
                                                        GError** error);
static GXmlDomNode* gxml_ghash_map_attr_real_remove_named_item_ns (GXmlDomNamedNodeMap* base,
                                                            const gchar* namespace_uri,
                                                            const gchar* local_name,
                                                            GError** error);
GType gxml_ghash_map_attr_entry_get_type (void) G_GNUC_CONST;
GXmlGHashMapAttrEntry* gxml_ghash_map_attr_entry_new (GXmlGDocument* doc,
                                                      xmlAttr* attr);
GXmlGHashMapAttrEntry* gxml_ghash_map_attr_entry_construct (GType object_type,
                                                            GXmlGDocument* doc,
                                                            xmlAttr* attr);
static void gxml_ghash_map_attr_entry_finalize (GObject * obj);
static void _vala_gxml_ghash_map_attr_entry_get_property (GObject * object,
                                                   guint property_id,
                                                   GValue * value,
                                                   GParamSpec * pspec);
static void _vala_gxml_ghash_map_attr_entry_set_property (GObject * object,
                                                   guint property_id,
                                                   const GValue * value,
                                                   GParamSpec * pspec);
static gchar* gxml_ghash_map_attr_iterator_real_get_key (GeeMapIterator* base);
static GXmlGNode* gxml_ghash_map_attr_iterator_real_get_value (GeeMapIterator* base);
static gboolean gxml_ghash_map_attr_iterator_real_has_next (GeeMapIterator* base);
static gboolean gxml_ghash_map_attr_iterator_real_next (GeeMapIterator* base);
static void gxml_ghash_map_attr_iterator_real_set_value (GeeMapIterator* base,
                                                  GXmlGNode* value);
gchar* gxml_gnode_get_name (GXmlGNode* self);
static void gxml_ghash_map_attr_iterator_real_unset (GeeMapIterator* base);
static void gxml_ghash_map_attr_iterator_finalize (GObject * obj);
static void _vala_gxml_ghash_map_attr_iterator_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec);
static void gxml_ghash_map_attr_finalize (GObject * obj);
gint gxml_dom_named_node_map_get_length (GXmlDomNamedNodeMap* self);
static void _vala_gxml_ghash_map_attr_get_property (GObject * object,
                                             guint property_id,
                                             GValue * value,
                                             GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static inline gpointer
gxml_ghash_map_attr_get_instance_private (GXmlGHashMapAttr* self)
{
	return G_STRUCT_MEMBER_P (self, GXmlGHashMapAttr_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

GXmlGHashMapAttr*
gxml_ghash_map_attr_construct (GType object_type,
                               GXmlGDocument* doc,
                               xmlNode* node)
{
	GXmlGHashMapAttr * self = NULL;
	GXmlGDocument* _tmp0_;
	g_return_val_if_fail (doc != NULL, NULL);
	self = (GXmlGHashMapAttr*) gee_abstract_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, GXML_TYPE_GNODE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
	self->priv->_node = node;
	_tmp0_ = _g_object_ref0 (doc);
	_g_object_unref0 (self->priv->_doc);
	self->priv->_doc = _tmp0_;
	return self;
}

GXmlGHashMapAttr*
gxml_ghash_map_attr_new (GXmlGDocument* doc,
                         xmlNode* node)
{
	return gxml_ghash_map_attr_construct (GXML_TYPE_GHASH_MAP_ATTR, doc, node);
}

static void
gxml_ghash_map_attr_real_clear (GeeAbstractMap* base)
{
	GXmlGHashMapAttr * self;
	xmlNode* _tmp0_;
	xmlAttr* p = NULL;
	xmlNode* _tmp1_;
	xmlAttr* _tmp2_;
	self = (GXmlGHashMapAttr*) base;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->properties;
	p = _tmp2_;
	while (TRUE) {
		xmlAttr* _tmp3_;
		xmlAttr* pn = NULL;
		xmlAttr* _tmp4_;
		xmlAttr* _tmp5_;
		xmlAttr* _tmp6_;
		xmlAttr* _tmp7_;
		_tmp3_ = p;
		if (!(_tmp3_ != NULL)) {
			break;
		}
		_tmp4_ = p;
		pn = _tmp4_;
		_tmp5_ = p;
		_tmp6_ = _tmp5_->next;
		p = _tmp6_;
		_tmp7_ = pn;
		xmlRemoveProp (_tmp7_);
	}
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
	result = _tmp0_ != NULL;
	return result;
}

static GXmlGNode*
gxml_ghash_map_attr_real_get (GeeAbstractMap* base,
                              const gchar* key)
{
	GXmlGHashMapAttr * self;
	GXmlGNode* result = NULL;
	GXmlGNode* nullnode = NULL;
	xmlNode* _tmp0_;
	xmlAttr* p = NULL;
	xmlNode* _tmp27_;
	xmlAttr* _tmp28_;
	xmlAttr* _tmp29_;
	xmlAttr* _tmp30_;
	xmlNs* _tmp31_;
	GXmlGDocument* _tmp38_;
	xmlAttr* _tmp39_;
	GXmlGAttribute* _tmp40_;
	self = (GXmlGHashMapAttr*) base;
	g_return_val_if_fail (key != NULL, NULL);
	nullnode = NULL;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = nullnode;
		return result;
	}
	if (string_contains (key, ":")) {
		gchar** pp = NULL;
		gchar** _tmp1_;
		gchar** _tmp2_;
		gint pp_length1;
		gint _pp_size_;
		gchar** _tmp3_;
		gint _tmp3__length1;
		xmlAttr* ps = NULL;
		xmlNode* _tmp4_;
		xmlAttr* _tmp5_;
		gchar* prefix = NULL;
		gchar** _tmp6_;
		gint _tmp6__length1;
		const gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* n = NULL;
		gchar** _tmp9_;
		gint _tmp9__length1;
		const gchar* _tmp10_;
		gchar* _tmp11_;
		_tmp2_ = _tmp1_ = g_strsplit (key, ":", 0);
		pp = _tmp2_;
		pp_length1 = _vala_array_length (_tmp1_);
		_pp_size_ = pp_length1;
		_tmp3_ = pp;
		_tmp3__length1 = pp_length1;
		if (_tmp3__length1 != 2) {
			result = nullnode;
			pp = (_vala_array_free (pp, pp_length1, (GDestroyNotify) g_free), NULL);
			return result;
		}
		_tmp4_ = self->priv->_node;
		_tmp5_ = _tmp4_->properties;
		ps = _tmp5_;
		_tmp6_ = pp;
		_tmp6__length1 = pp_length1;
		_tmp7_ = _tmp6_[0];
		_tmp8_ = g_strdup (_tmp7_);
		prefix = _tmp8_;
		_tmp9_ = pp;
		_tmp9__length1 = pp_length1;
		_tmp10_ = _tmp9_[1];
		_tmp11_ = g_strdup (_tmp10_);
		n = _tmp11_;
		while (TRUE) {
			xmlAttr* _tmp12_;
			xmlAttr* _tmp13_;
			const gchar* _tmp14_;
			const gchar* _tmp15_;
			xmlAttr* _tmp25_;
			xmlAttr* _tmp26_;
			_tmp12_ = ps;
			if (!(_tmp12_ != NULL)) {
				break;
			}
			_tmp13_ = ps;
			_tmp14_ = _tmp13_->name;
			_tmp15_ = n;
			if (g_strcmp0 (_tmp14_, _tmp15_) == 0) {
				xmlAttr* _tmp16_;
				xmlNs* _tmp17_;
				xmlAttr* _tmp18_;
				xmlNs* _tmp19_;
				const gchar* _tmp20_;
				const gchar* _tmp21_;
				_tmp16_ = ps;
				_tmp17_ = _tmp16_->ns;
				if (_tmp17_ == NULL) {
					continue;
				}
				_tmp18_ = ps;
				_tmp19_ = _tmp18_->ns;
				_tmp20_ = _tmp19_->prefix;
				_tmp21_ = prefix;
				if (g_strcmp0 (_tmp20_, _tmp21_) == 0) {
					GXmlGDocument* _tmp22_;
					xmlAttr* _tmp23_;
					GXmlGAttribute* _tmp24_;
					_tmp22_ = self->priv->_doc;
					_tmp23_ = ps;
					_tmp24_ = gxml_gattribute_new (_tmp22_, _tmp23_);
					result = (GXmlGNode*) _tmp24_;
					_g_free0 (n);
					_g_free0 (prefix);
					pp = (_vala_array_free (pp, pp_length1, (GDestroyNotify) g_free), NULL);
					_g_object_unref0 (nullnode);
					return result;
				}
			}
			_tmp25_ = ps;
			_tmp26_ = _tmp25_->next;
			ps = _tmp26_;
		}
		_g_free0 (n);
		_g_free0 (prefix);
		pp = (_vala_array_free (pp, pp_length1, (GDestroyNotify) g_free), NULL);
	}
	_tmp27_ = self->priv->_node;
	_tmp28_ = xmlHasProp (_tmp27_, (xmlChar*) key);
	p = _tmp28_;
	_tmp29_ = p;
	if (_tmp29_ == NULL) {
		result = nullnode;
		return result;
	}
	_tmp30_ = p;
	_tmp31_ = _tmp30_->ns;
	if (_tmp31_ != NULL) {
		xmlAttr* npns = NULL;
		xmlNode* _tmp32_;
		xmlAttr* _tmp33_;
		xmlAttr* _tmp34_;
		_tmp32_ = self->priv->_node;
		_tmp33_ = xmlHasNsProp (_tmp32_, (xmlChar*) key, (xmlChar*) NULL);
		npns = _tmp33_;
		_tmp34_ = npns;
		if (_tmp34_ != NULL) {
			GXmlGDocument* _tmp35_;
			xmlAttr* _tmp36_;
			GXmlGAttribute* _tmp37_;
			_tmp35_ = self->priv->_doc;
			_tmp36_ = npns;
			_tmp37_ = gxml_gattribute_new (_tmp35_, _tmp36_);
			result = (GXmlGNode*) _tmp37_;
			_g_object_unref0 (nullnode);
			return result;
		}
	}
	_tmp38_ = self->priv->_doc;
	_tmp39_ = p;
	_tmp40_ = gxml_gattribute_new (_tmp38_, _tmp39_);
	result = (GXmlGNode*) _tmp40_;
	_g_object_unref0 (nullnode);
	return result;
}

static gboolean
gxml_ghash_map_attr_real_has (GeeAbstractMap* base,
                              const gchar* key,
                              GXmlGNode* value)
{
	GXmlGHashMapAttr * self;
	gboolean result = FALSE;
	self = (GXmlGHashMapAttr*) base;
	g_return_val_if_fail (key != NULL, FALSE);
	g_return_val_if_fail (value != NULL, FALSE);
	result = gee_abstract_map_has_key ((GeeAbstractMap*) self, key);
	return result;
}

static gboolean
gxml_ghash_map_attr_real_has_key (GeeAbstractMap* base,
                                  const gchar* key)
{
	GXmlGHashMapAttr * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_;
	xmlAttr* p = NULL;
	xmlNode* _tmp1_;
	xmlAttr* _tmp2_;
	self = (GXmlGHashMapAttr*) base;
	g_return_val_if_fail (key != NULL, FALSE);
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->properties;
	p = _tmp2_;
	while (TRUE) {
		xmlAttr* _tmp3_;
		xmlAttr* _tmp4_;
		const gchar* _tmp5_;
		xmlAttr* _tmp6_;
		xmlAttr* _tmp7_;
		_tmp3_ = p;
		if (!(_tmp3_ != NULL)) {
			break;
		}
		_tmp4_ = p;
		_tmp5_ = _tmp4_->name;
		if (g_strcmp0 (_tmp5_, key) == 0) {
			result = TRUE;
			return result;
		}
		_tmp6_ = p;
		_tmp7_ = _tmp6_->next;
		p = _tmp7_;
	}
	result = FALSE;
	return result;
}

static GeeMapIterator*
gxml_ghash_map_attr_real_map_iterator (GeeAbstractMap* base)
{
	GXmlGHashMapAttr * self;
	GeeMapIterator* result = NULL;
	GXmlGDocument* _tmp0_;
	xmlNode* _tmp1_;
	GXmlGHashMapAttrIterator* _tmp2_;
	self = (GXmlGHashMapAttr*) base;
	_tmp0_ = self->priv->_doc;
	_tmp1_ = self->priv->_node;
	_tmp2_ = gxml_ghash_map_attr_iterator_new (_tmp0_, _tmp1_);
	result = (GeeMapIterator*) _tmp2_;
	return result;
}

static void
gxml_ghash_map_attr_real_set (GeeAbstractMap* base,
                              const gchar* key,
                              GXmlGNode* value)
{
	GXmlGHashMapAttr * self;
	xmlNode* _tmp0_;
	xmlNode* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	self = (GXmlGHashMapAttr*) base;
	g_return_if_fail (key != NULL);
	g_return_if_fail (value != NULL);
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = gxml_gnode_get_value (value);
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_;
	xmlNewProp (_tmp1_, (xmlChar*) key, (xmlChar*) _tmp4_);
	_g_free0 (_tmp4_);
}

static gboolean
gxml_ghash_map_attr_real_unset (GeeAbstractMap* base,
                                const gchar* key,
                                GXmlGNode* * value)
{
	GXmlGHashMapAttr * self;
	GXmlGNode* _vala_value = NULL;
	gboolean result = FALSE;
	xmlNode* _tmp0_;
	xmlAttr* p = NULL;
	xmlNode* _tmp1_;
	xmlAttr* _tmp2_;
	xmlAttr* _tmp3_;
	xmlAttr* _tmp4_;
	self = (GXmlGHashMapAttr*) base;
	g_return_val_if_fail (key != NULL, FALSE);
	_g_object_unref0 (_vala_value);
	_vala_value = NULL;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		if (value) {
			*value = _vala_value;
		} else {
			_g_object_unref0 (_vala_value);
		}
		return result;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = xmlHasProp (_tmp1_, (xmlChar*) key);
	p = _tmp2_;
	_tmp3_ = p;
	if (_tmp3_ == NULL) {
		result = FALSE;
		if (value) {
			*value = _vala_value;
		} else {
			_g_object_unref0 (_vala_value);
		}
		return result;
	}
	_tmp4_ = p;
	xmlRemoveProp (_tmp4_);
	result = TRUE;
	if (value) {
		*value = _vala_value;
	} else {
		_g_object_unref0 (_vala_value);
	}
	return result;
}

static GXmlDomNode*
gxml_ghash_map_attr_real_get_named_item (GXmlDomNamedNodeMap* base,
                                         const gchar* name)
{
	GXmlGHashMapAttr * self;
	GXmlDomNode* result = NULL;
	gpointer _tmp0_;
	self = (GXmlGHashMapAttr*) base;
	g_return_val_if_fail (name != NULL, NULL);
	_tmp0_ = gee_abstract_map_get ((GeeAbstractMap*) self, name);
	result = G_TYPE_CHECK_INSTANCE_CAST ((GXmlGNode*) _tmp0_, GXML_TYPE_DOM_NODE, GXmlDomNode);
	return result;
}

/**
   * Search items in this collection and return the object found at
   * index, but not order is warrantied
   *
   * If index is greather than collection size, then last element found
   * is returned. This function falls back to first element found on any
   * issue.
   *
   * @param index of required {@link DomNode}
   */
static GXmlDomNode*
gxml_ghash_map_attr_real_item (GXmlDomNamedNodeMap* base,
                               gint index)
{
	GXmlGHashMapAttr * self;
	GXmlDomNode* result = NULL;
	gint i = 0;
	gint _tmp0_;
	gint _tmp1_;
	self = (GXmlGHashMapAttr*) base;
	i = 0;
	_tmp0_ = gee_abstract_map_get_size ((GeeAbstractMap*) self);
	_tmp1_ = _tmp0_;
	if (index > _tmp1_) {
		result = NULL;
		return result;
	}
	{
		GeeIterator* _node_it = NULL;
		GeeCollection* _tmp2_;
		GeeCollection* _tmp3_;
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_;
		GeeIterator* _tmp6_;
		_tmp2_ = gee_abstract_map_get_values ((GeeAbstractMap*) self);
		_tmp3_ = _tmp2_;
		_tmp4_ = _tmp3_;
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
		_tmp6_ = _tmp5_;
		_g_object_unref0 (_tmp4_);
		_node_it = _tmp6_;
		while (TRUE) {
			GeeIterator* _tmp7_;
			GXmlGNode* node = NULL;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			_tmp7_ = _node_it;
			if (!gee_iterator_next (_tmp7_)) {
				break;
			}
			_tmp8_ = _node_it;
			_tmp9_ = gee_iterator_get (_tmp8_);
			node = (GXmlGNode*) _tmp9_;
			if (i == index) {
				GXmlGNode* _tmp10_;
				GXmlDomNode* _tmp11_;
				_tmp10_ = node;
				_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GXML_TYPE_DOM_NODE, GXmlDomNode));
				result = _tmp11_;
				_g_object_unref0 (node);
				_g_object_unref0 (_node_it);
				return result;
			}
			_g_object_unref0 (node);
		}
		_g_object_unref0 (_node_it);
	}
	result = NULL;
	return result;
}

static GXmlDomNode*
gxml_ghash_map_attr_real_set_named_item (GXmlDomNamedNodeMap* base,
                                         GXmlDomNode* node,
                                         GError** error)
{
	GXmlGHashMapAttr * self;
	GXmlDomNode* result = NULL;
	GeeIterator* _tmp0_;
	GeeIterator* _tmp1_;
	GXmlDomElement* _parent = NULL;
	GeeIterator* _tmp2_;
	GeeIterator* _tmp3_;
	gpointer _tmp4_;
	GeeMapEntry* _tmp5_;
	gconstpointer _tmp6_;
	GXmlDomNode* _tmp7_;
	GXmlDomNode* _tmp8_;
	GXmlDomNode* _tmp9_;
	GXmlDomElement* _tmp10_;
	GXmlDomElement* _tmp11_;
	gboolean _tmp12_ = FALSE;
	gint _tmp13_;
	gint _tmp14_;
	gboolean _tmp21_;
	gboolean _tmp22_;
	gboolean _tmp24_ = FALSE;
	gboolean _tmp30_ = FALSE;
	GXmlDomElement* _tmp31_;
	GXmlDomElement* _tmp33_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGHashMapAttr*) base;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp0_ = gee_iterable_iterator ((GeeIterable*) self);
	_tmp1_ = _tmp0_;
	gee_iterator_next (_tmp1_);
	_g_object_unref0 (_tmp1_);
	_tmp2_ = gee_iterable_iterator ((GeeIterable*) self);
	_tmp3_ = _tmp2_;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (GeeMapEntry*) _tmp4_;
	_tmp6_ = gee_map_entry_get_value (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp7_);
	_tmp9_ = _tmp8_;
	_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp9_) : NULL;
	if (_tmp10_ == NULL) {
		_g_object_unref0 (_tmp9_);
	}
	_tmp11_ = _tmp10_;
	_g_object_unref0 (_tmp5_);
	_g_object_unref0 (_tmp3_);
	_parent = _tmp11_;
	_tmp13_ = gee_abstract_map_get_size ((GeeAbstractMap*) self);
	_tmp14_ = _tmp13_;
	if (_tmp14_ > 0) {
		GXmlDomDocument* _tmp15_;
		GXmlDomDocument* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomDocument* _tmp18_;
		GXmlDomDocument* _tmp19_;
		_tmp15_ = gxml_dom_node_get_owner_document (node);
		_tmp16_ = _tmp15_;
		_tmp17_ = _parent;
		_tmp18_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp17_);
		_tmp19_ = _tmp18_;
		_tmp12_ = _tmp16_ != _tmp19_;
	} else {
		_tmp12_ = FALSE;
	}
	if (_tmp12_) {
		GError* _tmp20_;
		_tmp20_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR, _ ("Invalid document when adding item to collection"));
		_inner_error0_ = _tmp20_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (_parent);
		return NULL;
	}
	_tmp21_ = gee_abstract_map_get_read_only ((GeeAbstractMap*) self);
	_tmp22_ = _tmp21_;
	if (_tmp22_) {
		GError* _tmp23_;
		_tmp23_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR, _ ("This node collection is read only"));
		_inner_error0_ = _tmp23_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (_parent);
		return NULL;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR)) {
		GXmlDomElement* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomNode* _tmp28_;
		_tmp25_ = _parent;
		_tmp26_ = gxml_dom_node_get_parent_node (node);
		_tmp27_ = _tmp26_;
		_tmp28_ = _tmp27_;
		_tmp24_ = _tmp25_ != _tmp28_;
		_g_object_unref0 (_tmp28_);
	} else {
		_tmp24_ = FALSE;
	}
	if (_tmp24_) {
		GError* _tmp29_;
		_tmp29_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR, _ ("This node attribute is already in use by other Element"));
		_inner_error0_ = _tmp29_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (_parent);
		return NULL;
	}
	_tmp31_ = _parent;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_DOM_ELEMENT)) {
		_tmp30_ = !G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR);
	} else {
		_tmp30_ = FALSE;
	}
	if (_tmp30_) {
		GError* _tmp32_;
		_tmp32_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _ ("Trying to add an object to an Element, but it is not an attribute"));
		_inner_error0_ = _tmp32_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (_parent);
		return NULL;
	}
	_tmp33_ = _parent;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp33_, GXML_TYPE_DOM_ELEMENT)) {
		GXmlDomElement* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		GXmlDomNode* _tmp41_;
		_tmp34_ = _parent;
		_tmp35_ = gxml_dom_node_get_node_name (node);
		_tmp36_ = _tmp35_;
		_tmp37_ = _tmp36_;
		_tmp38_ = gxml_dom_node_get_node_value (node);
		_tmp39_ = _tmp38_;
		_tmp40_ = _tmp39_;
		gxml_dom_element_set_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp34_) : NULL, _tmp37_, _tmp40_, &_inner_error0_);
		_g_free0 (_tmp40_);
		_g_free0 (_tmp37_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (_parent);
			return NULL;
		}
		_tmp41_ = _g_object_ref0 (node);
		result = _tmp41_;
		_g_object_unref0 (_parent);
		return result;
	}
	result = NULL;
	_g_object_unref0 (_parent);
	return result;
}

static GXmlDomNode*
gxml_ghash_map_attr_real_remove_named_item (GXmlDomNamedNodeMap* base,
                                            const gchar* name,
                                            GError** error)
{
	GXmlGHashMapAttr * self;
	GXmlDomNode* result = NULL;
	GeeIterator* _tmp0_;
	GeeIterator* _tmp1_;
	GXmlDomElement* _parent = NULL;
	GeeIterator* _tmp2_;
	GeeIterator* _tmp3_;
	gpointer _tmp4_;
	GeeMapEntry* _tmp5_;
	gconstpointer _tmp6_;
	GXmlDomNode* _tmp7_;
	GXmlDomNode* _tmp8_;
	GXmlDomNode* _tmp9_;
	GXmlDomElement* _tmp10_;
	GXmlDomElement* _tmp11_;
	GXmlGNode* n = NULL;
	gpointer _tmp12_;
	GXmlGNode* _tmp13_;
	gboolean _tmp18_;
	gboolean _tmp19_;
	GXmlDomElement* _tmp21_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGHashMapAttr*) base;
	g_return_val_if_fail (name != NULL, NULL);
	_tmp0_ = gee_iterable_iterator ((GeeIterable*) self);
	_tmp1_ = _tmp0_;
	gee_iterator_next (_tmp1_);
	_g_object_unref0 (_tmp1_);
	_tmp2_ = gee_iterable_iterator ((GeeIterable*) self);
	_tmp3_ = _tmp2_;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (GeeMapEntry*) _tmp4_;
	_tmp6_ = gee_map_entry_get_value (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp7_);
	_tmp9_ = _tmp8_;
	_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp9_) : NULL;
	if (_tmp10_ == NULL) {
		_g_object_unref0 (_tmp9_);
	}
	_tmp11_ = _tmp10_;
	_g_object_unref0 (_tmp5_);
	_g_object_unref0 (_tmp3_);
	_parent = _tmp11_;
	_tmp12_ = GEE_ABSTRACT_MAP_CLASS (gxml_ghash_map_attr_parent_class)->get (G_TYPE_CHECK_INSTANCE_CAST (self, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), name);
	n = (GXmlGNode*) _tmp12_;
	_tmp13_ = n;
	if (_tmp13_ == NULL) {
		gchar* _tmp14_;
		gchar* _tmp15_;
		GError* _tmp16_;
		GError* _tmp17_;
		_tmp14_ = g_strdup_printf ("No node with name %s was found", name);
		_tmp15_ = _tmp14_;
		_tmp16_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NOT_FOUND_ERROR, _ (_tmp15_));
		_tmp17_ = _tmp16_;
		_g_free0 (_tmp15_);
		_inner_error0_ = _tmp17_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (n);
		_g_object_unref0 (_parent);
		return NULL;
	}
	_tmp18_ = gee_abstract_map_get_read_only ((GeeAbstractMap*) self);
	_tmp19_ = _tmp18_;
	if (_tmp19_) {
		GError* _tmp20_;
		_tmp20_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR, _ ("Node collection is read only"));
		_inner_error0_ = _tmp20_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (n);
		_g_object_unref0 (_parent);
		return NULL;
	}
	_tmp21_ = _parent;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, GXML_TYPE_DOM_ELEMENT)) {
		GXmlDomNode* a = NULL;
		GXmlDomElement* _tmp22_;
		GXmlDomNamedNodeMap* _tmp23_;
		GXmlDomNamedNodeMap* _tmp24_;
		GXmlDomNamedNodeMap* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomElement* _tmp28_;
		xmlNode* _tmp29_;
		_tmp22_ = _parent;
		_tmp23_ = gxml_dom_element_get_attributes (_tmp22_);
		_tmp24_ = _tmp23_;
		_tmp25_ = _tmp24_;
		_tmp26_ = gxml_dom_named_node_map_get_named_item (_tmp25_, name);
		_tmp27_ = _tmp26_;
		_g_object_unref0 (_tmp25_);
		a = _tmp27_;
		_tmp28_ = _parent;
		_tmp29_ = gxml_gnode_get_internal_node (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, GXML_TYPE_GNODE) ? ((GXmlGNode*) _tmp28_) : NULL);
		xmlSetProp (_tmp29_, (xmlChar*) name, (xmlChar*) NULL);
		result = a;
		_g_object_unref0 (n);
		_g_object_unref0 (_parent);
		return result;
	}
	result = NULL;
	_g_object_unref0 (n);
	_g_object_unref0 (_parent);
	return result;
}

static GXmlDomNode*
gxml_ghash_map_attr_real_get_named_item_ns (GXmlDomNamedNodeMap* base,
                                            const gchar* namespace_uri,
                                            const gchar* local_name,
                                            GError** error)
{
	GXmlGHashMapAttr * self;
	GXmlDomNode* result = NULL;
	self = (GXmlGHashMapAttr*) base;
	g_return_val_if_fail (namespace_uri != NULL, NULL);
	g_return_val_if_fail (local_name != NULL, NULL);
	{
		GeeIterator* _n_it = NULL;
		GeeCollection* _tmp0_;
		GeeCollection* _tmp1_;
		GeeCollection* _tmp2_;
		GeeIterator* _tmp3_;
		GeeIterator* _tmp4_;
		_tmp0_ = gee_abstract_map_get_values ((GeeAbstractMap*) self);
		_tmp1_ = _tmp0_;
		_tmp2_ = _tmp1_;
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
		_tmp4_ = _tmp3_;
		_g_object_unref0 (_tmp2_);
		_n_it = _tmp4_;
		while (TRUE) {
			GeeIterator* _tmp5_;
			GXmlDomNode* n = NULL;
			GeeIterator* _tmp6_;
			gpointer _tmp7_;
			gchar* uri = NULL;
			gchar* _tmp8_;
			gboolean _tmp9_ = FALSE;
			GXmlDomNode* _tmp10_;
			GXmlDomNode* _tmp12_;
			GXmlDomNode* _tmp21_;
			gboolean _tmp30_ = FALSE;
			const gchar* _tmp31_;
			_tmp5_ = _n_it;
			if (!gee_iterator_next (_tmp5_)) {
				break;
			}
			_tmp6_ = _n_it;
			_tmp7_ = gee_iterator_get (_tmp6_);
			n = (GXmlDomNode*) ((GXmlGNode*) _tmp7_);
			_tmp8_ = g_strdup ("");
			uri = _tmp8_;
			_tmp10_ = n;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, GXML_TYPE_DOM_ELEMENT)) {
				_tmp9_ = TRUE;
			} else {
				GXmlDomNode* _tmp11_;
				_tmp11_ = n;
				_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, GXML_TYPE_DOM_ATTR);
			}
			if (!_tmp9_) {
				_g_free0 (uri);
				_g_object_unref0 (n);
				continue;
			}
			_tmp12_ = n;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_DOM_ELEMENT)) {
				GXmlDomNode* _tmp13_;
				gchar* _tmp14_;
				gchar* _tmp15_;
				gchar* _tmp16_;
				gboolean _tmp17_;
				GXmlDomNode* _tmp18_;
				gchar* _tmp19_;
				gchar* _tmp20_;
				_tmp13_ = n;
				_tmp14_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp13_) : NULL);
				_tmp15_ = _tmp14_;
				_tmp16_ = _tmp15_;
				_tmp17_ = _tmp16_ == NULL;
				_g_free0 (_tmp16_);
				if (_tmp17_) {
					_g_free0 (uri);
					_g_object_unref0 (n);
					continue;
				}
				_tmp18_ = n;
				_tmp19_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp18_) : NULL);
				_tmp20_ = _tmp19_;
				_g_free0 (uri);
				uri = _tmp20_;
			}
			_tmp21_ = n;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, GXML_TYPE_DOM_ATTR)) {
				GXmlDomNode* _tmp22_;
				gchar* _tmp23_;
				gchar* _tmp24_;
				gchar* _tmp25_;
				gboolean _tmp26_;
				GXmlDomNode* _tmp27_;
				gchar* _tmp28_;
				gchar* _tmp29_;
				_tmp22_ = n;
				_tmp23_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp22_) : NULL);
				_tmp24_ = _tmp23_;
				_tmp25_ = _tmp24_;
				_tmp26_ = _tmp25_ == NULL;
				_g_free0 (_tmp25_);
				if (_tmp26_) {
					_g_free0 (uri);
					_g_object_unref0 (n);
					continue;
				}
				_tmp27_ = n;
				_tmp28_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp27_) : NULL);
				_tmp29_ = _tmp28_;
				_g_free0 (uri);
				uri = _tmp29_;
			}
			_tmp31_ = uri;
			if (g_strcmp0 (_tmp31_, namespace_uri) == 0) {
				GXmlDomNode* _tmp32_;
				gchar* _tmp33_;
				gchar* _tmp34_;
				gchar* _tmp35_;
				_tmp32_ = n;
				_tmp33_ = gxml_dom_node_get_node_name (_tmp32_);
				_tmp34_ = _tmp33_;
				_tmp35_ = _tmp34_;
				_tmp30_ = g_strcmp0 (_tmp35_, local_name) == 0;
				_g_free0 (_tmp35_);
			} else {
				_tmp30_ = FALSE;
			}
			if (_tmp30_) {
				GXmlDomNode* _tmp36_;
				GXmlDomNode* _tmp37_;
				_tmp36_ = n;
				_tmp37_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, GXML_TYPE_DOM_NODE, GXmlDomNode));
				result = _tmp37_;
				_g_free0 (uri);
				_g_object_unref0 (n);
				_g_object_unref0 (_n_it);
				return result;
			}
			_g_free0 (uri);
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_it);
	}
	result = NULL;
	return result;
}

static GXmlDomNode*
gxml_ghash_map_attr_real_set_named_item_ns (GXmlDomNamedNodeMap* base,
                                            GXmlDomNode* node,
                                            GError** error)
{
	GXmlGHashMapAttr * self;
	GXmlDomNode* result = NULL;
	GeeIterator* _tmp0_;
	GeeIterator* _tmp1_;
	GXmlDomElement* _parent = NULL;
	GeeIterator* _tmp2_;
	GeeIterator* _tmp3_;
	gpointer _tmp4_;
	GeeMapEntry* _tmp5_;
	gconstpointer _tmp6_;
	GXmlDomNode* _tmp7_;
	GXmlDomNode* _tmp8_;
	GXmlDomNode* _tmp9_;
	GXmlDomElement* _tmp10_;
	GXmlDomElement* _tmp11_;
	gboolean _tmp12_ = FALSE;
	gint _tmp13_;
	gint _tmp14_;
	gboolean _tmp21_;
	gboolean _tmp22_;
	gboolean _tmp24_ = FALSE;
	gboolean _tmp30_ = FALSE;
	GXmlDomElement* _tmp31_;
	gboolean _tmp33_ = FALSE;
	GXmlDomElement* _tmp34_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGHashMapAttr*) base;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp0_ = gee_iterable_iterator ((GeeIterable*) self);
	_tmp1_ = _tmp0_;
	gee_iterator_next (_tmp1_);
	_g_object_unref0 (_tmp1_);
	_tmp2_ = gee_iterable_iterator ((GeeIterable*) self);
	_tmp3_ = _tmp2_;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (GeeMapEntry*) _tmp4_;
	_tmp6_ = gee_map_entry_get_value (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp7_);
	_tmp9_ = _tmp8_;
	_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp9_) : NULL;
	if (_tmp10_ == NULL) {
		_g_object_unref0 (_tmp9_);
	}
	_tmp11_ = _tmp10_;
	_g_object_unref0 (_tmp5_);
	_g_object_unref0 (_tmp3_);
	_parent = _tmp11_;
	_tmp13_ = gee_abstract_map_get_size ((GeeAbstractMap*) self);
	_tmp14_ = _tmp13_;
	if (_tmp14_ > 0) {
		GXmlDomDocument* _tmp15_;
		GXmlDomDocument* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomDocument* _tmp18_;
		GXmlDomDocument* _tmp19_;
		_tmp15_ = gxml_dom_node_get_owner_document (node);
		_tmp16_ = _tmp15_;
		_tmp17_ = _parent;
		_tmp18_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp17_);
		_tmp19_ = _tmp18_;
		_tmp12_ = _tmp16_ != _tmp19_;
	} else {
		_tmp12_ = FALSE;
	}
	if (_tmp12_) {
		GError* _tmp20_;
		_tmp20_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR, _ ("Invalid document when adding item to named node map collection"));
		_inner_error0_ = _tmp20_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (_parent);
		return NULL;
	}
	_tmp21_ = gee_abstract_map_get_read_only ((GeeAbstractMap*) self);
	_tmp22_ = _tmp21_;
	if (_tmp22_) {
		GError* _tmp23_;
		_tmp23_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR, _ ("This node collection is read only"));
		_inner_error0_ = _tmp23_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (_parent);
		return NULL;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR)) {
		GXmlDomElement* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomNode* _tmp28_;
		_tmp25_ = _parent;
		_tmp26_ = gxml_dom_node_get_parent_node (node);
		_tmp27_ = _tmp26_;
		_tmp28_ = _tmp27_;
		_tmp24_ = _tmp25_ != _tmp28_;
		_g_object_unref0 (_tmp28_);
	} else {
		_tmp24_ = FALSE;
	}
	if (_tmp24_) {
		GError* _tmp29_;
		_tmp29_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR, _ ("This node attribute is already in use by other Element"));
		_inner_error0_ = _tmp29_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (_parent);
		return NULL;
	}
	_tmp31_ = _parent;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_DOM_ELEMENT)) {
		_tmp30_ = !G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR);
	} else {
		_tmp30_ = FALSE;
	}
	if (_tmp30_) {
		GError* _tmp32_;
		_tmp32_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _ ("Trying to add an object to an Element, but it is not an attribute"));
		_inner_error0_ = _tmp32_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (_parent);
		return NULL;
	}
	_tmp34_ = _parent;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, GXML_TYPE_DOM_ELEMENT)) {
		_tmp33_ = G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR);
	} else {
		_tmp33_ = FALSE;
	}
	if (_tmp33_) {
		GXmlDomElement* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		gchar* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		gchar* _tmp51_;
		GXmlDomNode* _tmp52_ = NULL;
		GXmlDomElement* _tmp53_;
		GXmlDomNamedNodeMap* _tmp54_;
		GXmlDomNamedNodeMap* _tmp55_;
		GXmlDomNamedNodeMap* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		gchar* _tmp59_;
		gchar* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
		gchar* _tmp66_;
		gchar* _tmp67_;
		gchar* _tmp68_;
		gchar* _tmp69_;
		GXmlDomNode* _tmp70_;
		GXmlDomNode* _tmp71_;
		GXmlDomNode* _tmp72_;
		_tmp35_ = _parent;
		_tmp36_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp37_ = _tmp36_;
		_tmp38_ = _tmp37_;
		_tmp39_ = g_strconcat (_tmp38_, ":", NULL);
		_tmp40_ = _tmp39_;
		_tmp41_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp42_ = _tmp41_;
		_tmp43_ = _tmp42_;
		_tmp44_ = g_strconcat (_tmp40_, _tmp43_, NULL);
		_tmp45_ = _tmp44_;
		_tmp46_ = gxml_dom_node_get_node_name (node);
		_tmp47_ = _tmp46_;
		_tmp48_ = _tmp47_;
		_tmp49_ = gxml_dom_node_get_node_value (node);
		_tmp50_ = _tmp49_;
		_tmp51_ = _tmp50_;
		gxml_dom_element_set_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp35_) : NULL, _tmp45_, _tmp48_, _tmp51_, &_inner_error0_);
		_g_free0 (_tmp51_);
		_g_free0 (_tmp48_);
		_g_free0 (_tmp45_);
		_g_free0 (_tmp43_);
		_g_free0 (_tmp40_);
		_g_free0 (_tmp38_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (_parent);
			return NULL;
		}
		_tmp53_ = _parent;
		_tmp54_ = gxml_dom_element_get_attributes (_tmp53_);
		_tmp55_ = _tmp54_;
		_tmp56_ = _tmp55_;
		_tmp57_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp58_ = _tmp57_;
		_tmp59_ = _tmp58_;
		_tmp60_ = g_strconcat (_tmp59_, ":", NULL);
		_tmp61_ = _tmp60_;
		_tmp62_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp63_ = _tmp62_;
		_tmp64_ = _tmp63_;
		_tmp65_ = g_strconcat (_tmp61_, _tmp64_, NULL);
		_tmp66_ = _tmp65_;
		_tmp67_ = gxml_dom_node_get_node_name (node);
		_tmp68_ = _tmp67_;
		_tmp69_ = _tmp68_;
		_tmp70_ = gxml_dom_named_node_map_get_named_item_ns (_tmp56_, _tmp66_, _tmp69_, &_inner_error0_);
		_tmp71_ = _tmp70_;
		_g_free0 (_tmp69_);
		_g_free0 (_tmp66_);
		_g_free0 (_tmp64_);
		_g_free0 (_tmp61_);
		_g_free0 (_tmp59_);
		_g_object_unref0 (_tmp56_);
		_tmp52_ = _tmp71_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (_parent);
			return NULL;
		}
		_tmp72_ = _tmp52_;
		_tmp52_ = NULL;
		result = _tmp72_;
		_g_object_unref0 (_tmp52_);
		_g_object_unref0 (_parent);
		return result;
	}
	result = NULL;
	_g_object_unref0 (_parent);
	return result;
}

static GXmlDomNode*
gxml_ghash_map_attr_real_remove_named_item_ns (GXmlDomNamedNodeMap* base,
                                               const gchar* namespace_uri,
                                               const gchar* local_name,
                                               GError** error)
{
	GXmlGHashMapAttr * self;
	GXmlDomNode* result = NULL;
	GeeIterator* _tmp0_;
	GeeIterator* _tmp1_;
	GXmlDomElement* _parent = NULL;
	GeeIterator* _tmp2_;
	GeeIterator* _tmp3_;
	gpointer _tmp4_;
	GeeMapEntry* _tmp5_;
	gconstpointer _tmp6_;
	GXmlDomNode* _tmp7_;
	GXmlDomNode* _tmp8_;
	GXmlDomNode* _tmp9_;
	GXmlDomElement* _tmp10_;
	GXmlDomElement* _tmp11_;
	GXmlDomElement* _tmp12_;
	GXmlDomNode* n = NULL;
	GXmlDomElement* _tmp13_;
	GXmlDomNamedNodeMap* _tmp14_;
	GXmlDomNamedNodeMap* _tmp15_;
	GXmlDomNamedNodeMap* _tmp16_;
	GXmlDomNode* _tmp17_;
	GXmlDomNode* _tmp18_;
	GXmlDomNode* _tmp19_;
	gboolean _tmp24_;
	gboolean _tmp25_;
	GXmlDomElement* _tmp27_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGHashMapAttr*) base;
	g_return_val_if_fail (namespace_uri != NULL, NULL);
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = gee_iterable_iterator ((GeeIterable*) self);
	_tmp1_ = _tmp0_;
	gee_iterator_next (_tmp1_);
	_g_object_unref0 (_tmp1_);
	_tmp2_ = gee_iterable_iterator ((GeeIterable*) self);
	_tmp3_ = _tmp2_;
	_tmp4_ = gee_iterator_get (_tmp3_);
	_tmp5_ = (GeeMapEntry*) _tmp4_;
	_tmp6_ = gee_map_entry_get_value (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp7_);
	_tmp9_ = _tmp8_;
	_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp9_) : NULL;
	if (_tmp10_ == NULL) {
		_g_object_unref0 (_tmp9_);
	}
	_tmp11_ = _tmp10_;
	_g_object_unref0 (_tmp5_);
	_g_object_unref0 (_tmp3_);
	_parent = _tmp11_;
	_tmp12_ = _parent;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_DOM_ELEMENT)) {
		result = NULL;
		_g_object_unref0 (_parent);
		return result;
	}
	_tmp13_ = _parent;
	_tmp14_ = gxml_dom_element_get_attributes (_tmp13_);
	_tmp15_ = _tmp14_;
	_tmp16_ = _tmp15_;
	_tmp17_ = gxml_dom_named_node_map_get_named_item_ns (_tmp16_, namespace_uri, local_name, &_inner_error0_);
	_tmp18_ = _tmp17_;
	_g_object_unref0 (_tmp16_);
	n = _tmp18_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (_parent);
		return NULL;
	}
	_tmp19_ = n;
	if (_tmp19_ == NULL) {
		gchar* _tmp20_;
		gchar* _tmp21_;
		GError* _tmp22_;
		GError* _tmp23_;
		_tmp20_ = g_strdup_printf ("No node with name %s was found", local_name);
		_tmp21_ = _tmp20_;
		_tmp22_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NOT_FOUND_ERROR, _ (_tmp21_));
		_tmp23_ = _tmp22_;
		_g_free0 (_tmp21_);
		_inner_error0_ = _tmp23_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (n);
		_g_object_unref0 (_parent);
		return NULL;
	}
	_tmp24_ = gee_abstract_map_get_read_only ((GeeAbstractMap*) self);
	_tmp25_ = _tmp24_;
	if (_tmp25_) {
		GError* _tmp26_;
		_tmp26_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR, _ ("Node collection is read only"));
		_inner_error0_ = _tmp26_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (n);
		_g_object_unref0 (_parent);
		return NULL;
	}
	_tmp27_ = _parent;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, GXML_TYPE_DOM_ELEMENT)) {
		xmlNs* ns = NULL;
		GXmlDomElement* _tmp28_;
		xmlNode* _tmp29_;
		xmlDoc* _tmp30_;
		GXmlDomElement* _tmp31_;
		xmlNode* _tmp32_;
		xmlNs* _tmp33_;
		GXmlDomElement* _tmp34_;
		xmlNode* _tmp35_;
		xmlNs* _tmp36_;
		_tmp28_ = _parent;
		_tmp29_ = gxml_gnode_get_internal_node (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, GXML_TYPE_GNODE) ? ((GXmlGNode*) _tmp28_) : NULL);
		_tmp30_ = _tmp29_->doc;
		_tmp31_ = _parent;
		_tmp32_ = gxml_gnode_get_internal_node (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_GNODE) ? ((GXmlGNode*) _tmp31_) : NULL);
		_tmp33_ = xmlSearchNsByHref (_tmp30_, _tmp32_, namespace_uri);
		ns = _tmp33_;
		_tmp34_ = _parent;
		_tmp35_ = gxml_gnode_get_internal_node (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, GXML_TYPE_GNODE) ? ((GXmlGNode*) _tmp34_) : NULL);
		_tmp36_ = ns;
		xmlSetNsProp (_tmp35_, _tmp36_, (xmlChar*) local_name, (xmlChar*) NULL);
		result = n;
		_g_object_unref0 (_parent);
		return result;
	}
	result = NULL;
	_g_object_unref0 (n);
	_g_object_unref0 (_parent);
	return result;
}

static GeeSet*
gxml_ghash_map_attr_real_get_entries (GeeAbstractMap* base)
{
	GeeSet* result;
	GXmlGHashMapAttr* self;
	GeeHashSet* l = NULL;
	GeeHashSet* _tmp0_;
	xmlNode* _tmp1_;
	xmlAttr* p = NULL;
	xmlNode* _tmp2_;
	xmlAttr* _tmp3_;
	self = (GXmlGHashMapAttr*) base;
	_tmp0_ = gee_hash_set_new (GXML_GHASH_MAP_ATTR_TYPE_ENTRY, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
	l = _tmp0_;
	_tmp1_ = self->priv->_node;
	if (_tmp1_ == NULL) {
		result = (GeeSet*) l;
		return result;
	}
	_tmp2_ = self->priv->_node;
	_tmp3_ = _tmp2_->properties;
	p = _tmp3_;
	while (TRUE) {
		xmlAttr* _tmp4_;
		GXmlGHashMapAttrEntry* e = NULL;
		GXmlGDocument* _tmp5_;
		xmlAttr* _tmp6_;
		GXmlGHashMapAttrEntry* _tmp7_;
		GeeHashSet* _tmp8_;
		GXmlGHashMapAttrEntry* _tmp9_;
		xmlAttr* _tmp10_;
		xmlAttr* _tmp11_;
		_tmp4_ = p;
		if (!(_tmp4_ != NULL)) {
			break;
		}
		_tmp5_ = self->priv->_doc;
		_tmp6_ = p;
		_tmp7_ = gxml_ghash_map_attr_entry_new (_tmp5_, _tmp6_);
		e = _tmp7_;
		_tmp8_ = l;
		_tmp9_ = e;
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp8_, _tmp9_);
		_tmp10_ = p;
		_tmp11_ = _tmp10_->next;
		p = _tmp11_;
		_g_object_unref0 (e);
	}
	result = (GeeSet*) l;
	return result;
}

static GeeSet*
gxml_ghash_map_attr_real_get_keys (GeeAbstractMap* base)
{
	GeeSet* result;
	GXmlGHashMapAttr* self;
	GeeHashSet* l = NULL;
	GeeHashSet* _tmp0_;
	xmlNode* _tmp1_;
	xmlAttr* p = NULL;
	xmlNode* _tmp2_;
	xmlAttr* _tmp3_;
	self = (GXmlGHashMapAttr*) base;
	_tmp0_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL, NULL, NULL, NULL);
	l = _tmp0_;
	_tmp1_ = self->priv->_node;
	if (_tmp1_ == NULL) {
		result = (GeeSet*) l;
		return result;
	}
	_tmp2_ = self->priv->_node;
	_tmp3_ = _tmp2_->properties;
	p = _tmp3_;
	while (TRUE) {
		xmlAttr* _tmp4_;
		GeeHashSet* _tmp5_;
		xmlAttr* _tmp6_;
		const gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		xmlAttr* _tmp10_;
		xmlAttr* _tmp11_;
		_tmp4_ = p;
		if (!(_tmp4_ != NULL)) {
			break;
		}
		_tmp5_ = l;
		_tmp6_ = p;
		_tmp7_ = _tmp6_->name;
		_tmp8_ = g_strdup (_tmp7_);
		_tmp9_ = _tmp8_;
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp5_, _tmp9_);
		_g_free0 (_tmp9_);
		_tmp10_ = p;
		_tmp11_ = _tmp10_->next;
		p = _tmp11_;
	}
	result = (GeeSet*) l;
	return result;
}

static gboolean
gxml_ghash_map_attr_real_get_read_only (GeeAbstractMap* base)
{
	gboolean result;
	GXmlGHashMapAttr* self;
	self = (GXmlGHashMapAttr*) base;
	result = FALSE;
	return result;
}

static gint
gxml_ghash_map_attr_real_get_size (GeeAbstractMap* base)
{
	gint result;
	GXmlGHashMapAttr* self;
	xmlAttr* p = NULL;
	xmlNode* _tmp0_;
	xmlAttr* _tmp1_;
	gint i = 0;
	self = (GXmlGHashMapAttr*) base;
	_tmp0_ = self->priv->_node;
	_tmp1_ = _tmp0_->properties;
	p = _tmp1_;
	i = 0;
	while (TRUE) {
		xmlAttr* _tmp2_;
		xmlAttr* _tmp3_;
		xmlAttr* _tmp4_;
		gint _tmp5_;
		_tmp2_ = p;
		if (!(_tmp2_ != NULL)) {
			break;
		}
		_tmp3_ = p;
		_tmp4_ = _tmp3_->next;
		p = _tmp4_;
		_tmp5_ = i;
		i = _tmp5_ + 1;
	}
	result = i;
	return result;
}

static GeeCollection*
gxml_ghash_map_attr_real_get_values (GeeAbstractMap* base)
{
	GeeCollection* result;
	GXmlGHashMapAttr* self;
	GeeArrayList* l = NULL;
	GeeArrayList* _tmp0_;
	xmlAttr* p = NULL;
	xmlNode* _tmp1_;
	xmlAttr* _tmp2_;
	self = (GXmlGHashMapAttr*) base;
	_tmp0_ = gee_array_list_new (GXML_TYPE_GNODE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
	l = _tmp0_;
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->properties;
	p = _tmp2_;
	while (TRUE) {
		xmlAttr* _tmp3_;
		GeeArrayList* _tmp4_;
		GXmlGDocument* _tmp5_;
		xmlAttr* _tmp6_;
		GXmlGAttribute* _tmp7_;
		GXmlGAttribute* _tmp8_;
		xmlAttr* _tmp9_;
		xmlAttr* _tmp10_;
		_tmp3_ = p;
		if (!(_tmp3_ != NULL)) {
			break;
		}
		_tmp4_ = l;
		_tmp5_ = self->priv->_doc;
		_tmp6_ = p;
		_tmp7_ = gxml_gattribute_new (_tmp5_, _tmp6_);
		_tmp8_ = _tmp7_;
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp4_, (GXmlGNode*) _tmp8_);
		_g_object_unref0 (_tmp8_);
		_tmp9_ = p;
		_tmp10_ = _tmp9_->next;
		p = _tmp10_;
	}
	result = (GeeCollection*) l;
	return result;
}

static gint
gxml_ghash_map_attr_real_get_length (GXmlDomNamedNodeMap* base)
{
	gint result;
	GXmlGHashMapAttr* self;
	gint _tmp0_;
	gint _tmp1_;
	self = (GXmlGHashMapAttr*) base;
	_tmp0_ = gee_abstract_map_get_size ((GeeAbstractMap*) self);
	_tmp1_ = _tmp0_;
	result = _tmp1_;
	return result;
}

static inline gpointer
gxml_ghash_map_attr_entry_get_instance_private (GXmlGHashMapAttrEntry* self)
{
	return G_STRUCT_MEMBER_P (self, GXmlGHashMapAttrEntry_private_offset);
}

GXmlGHashMapAttrEntry*
gxml_ghash_map_attr_entry_construct (GType object_type,
                                     GXmlGDocument* doc,
                                     xmlAttr* attr)
{
	GXmlGHashMapAttrEntry * self = NULL;
	GXmlGDocument* _tmp0_;
	GXmlGDocument* _tmp1_;
	xmlAttr* _tmp2_;
	GXmlGAttribute* _tmp3_;
	g_return_val_if_fail (doc != NULL, NULL);
	self = (GXmlGHashMapAttrEntry*) gee_map_entry_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, GXML_TYPE_GNODE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
	self->priv->_attr = attr;
	_tmp0_ = _g_object_ref0 (doc);
	_g_object_unref0 (self->priv->_doc);
	self->priv->_doc = _tmp0_;
	_tmp1_ = self->priv->_doc;
	_tmp2_ = self->priv->_attr;
	_tmp3_ = gxml_gattribute_new (_tmp1_, _tmp2_);
	_g_object_unref0 (self->priv->oattr);
	self->priv->oattr = _tmp3_;
	return self;
}

GXmlGHashMapAttrEntry*
gxml_ghash_map_attr_entry_new (GXmlGDocument* doc,
                               xmlAttr* attr)
{
	return gxml_ghash_map_attr_entry_construct (GXML_GHASH_MAP_ATTR_TYPE_ENTRY, doc, attr);
}

static const gchar*
gxml_ghash_map_attr_entry_real_get_key (GeeMapEntry* base)
{
	const gchar* result;
	GXmlGHashMapAttrEntry* self;
	xmlAttr* _tmp0_;
	const gchar* _tmp1_;
	self = (GXmlGHashMapAttrEntry*) base;
	_tmp0_ = self->priv->_attr;
	_tmp1_ = _tmp0_->name;
	result = _tmp1_;
	return result;
}

static gboolean
gxml_ghash_map_attr_entry_real_get_read_only (GeeMapEntry* base)
{
	gboolean result;
	GXmlGHashMapAttrEntry* self;
	self = (GXmlGHashMapAttrEntry*) base;
	result = TRUE;
	return result;
}

static GXmlGNode*
gxml_ghash_map_attr_entry_real_get_value (GeeMapEntry* base)
{
	GXmlGNode* result;
	GXmlGHashMapAttrEntry* self;
	GXmlGAttribute* _tmp0_;
	self = (GXmlGHashMapAttrEntry*) base;
	_tmp0_ = self->priv->oattr;
	result = (GXmlGNode*) _tmp0_;
	return result;
}

static void
gxml_ghash_map_attr_entry_real_set_value (GeeMapEntry* base,
                                          GXmlGNode* value)
{
	GXmlGHashMapAttrEntry* self;
	self = (GXmlGHashMapAttrEntry*) base;
	g_object_notify_by_pspec ((GObject *) self, gxml_ghash_map_attr_entry_properties[GXML_GHASH_MAP_ATTR_ENTRY_VALUE_PROPERTY]);
}

static void
gxml_ghash_map_attr_entry_class_init (GXmlGHashMapAttrEntryClass * klass,
                                      gpointer klass_data)
{
	gxml_ghash_map_attr_entry_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GXmlGHashMapAttrEntry_private_offset);
	GEE_MAP_ENTRY_CLASS (klass)->get_key = gxml_ghash_map_attr_entry_real_get_key;
	GEE_MAP_ENTRY_CLASS (klass)->get_read_only = gxml_ghash_map_attr_entry_real_get_read_only;
	GEE_MAP_ENTRY_CLASS (klass)->get_value = gxml_ghash_map_attr_entry_real_get_value;
	GEE_MAP_ENTRY_CLASS (klass)->set_value = gxml_ghash_map_attr_entry_real_set_value;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_ghash_map_attr_entry_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_ghash_map_attr_entry_set_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_ghash_map_attr_entry_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GHASH_MAP_ATTR_ENTRY_KEY_PROPERTY, gxml_ghash_map_attr_entry_properties[GXML_GHASH_MAP_ATTR_ENTRY_KEY_PROPERTY] = g_param_spec_string ("key", "key", "key", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GHASH_MAP_ATTR_ENTRY_READ_ONLY_PROPERTY, gxml_ghash_map_attr_entry_properties[GXML_GHASH_MAP_ATTR_ENTRY_READ_ONLY_PROPERTY] = g_param_spec_boolean ("read-only", "read-only", "read-only", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GHASH_MAP_ATTR_ENTRY_VALUE_PROPERTY, gxml_ghash_map_attr_entry_properties[GXML_GHASH_MAP_ATTR_ENTRY_VALUE_PROPERTY] = g_param_spec_object ("value", "value", "value", GXML_TYPE_GNODE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
gxml_ghash_map_attr_entry_instance_init (GXmlGHashMapAttrEntry * self,
                                         gpointer klass)
{
	self->priv = gxml_ghash_map_attr_entry_get_instance_private (self);
}

static void
gxml_ghash_map_attr_entry_finalize (GObject * obj)
{
	GXmlGHashMapAttrEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_GHASH_MAP_ATTR_TYPE_ENTRY, GXmlGHashMapAttrEntry);
	_g_object_unref0 (self->priv->_doc);
	_g_object_unref0 (self->priv->oattr);
	G_OBJECT_CLASS (gxml_ghash_map_attr_entry_parent_class)->finalize (obj);
}

GType
gxml_ghash_map_attr_entry_get_type (void)
{
	static volatile gsize gxml_ghash_map_attr_entry_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ghash_map_attr_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGHashMapAttrEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_ghash_map_attr_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGHashMapAttrEntry), 0, (GInstanceInitFunc) gxml_ghash_map_attr_entry_instance_init, NULL };
		GType gxml_ghash_map_attr_entry_type_id;
		gxml_ghash_map_attr_entry_type_id = g_type_register_static (GEE_MAP_TYPE_ENTRY, "GXmlGHashMapAttrEntry", &g_define_type_info, 0);
		GXmlGHashMapAttrEntry_private_offset = g_type_add_instance_private (gxml_ghash_map_attr_entry_type_id, sizeof (GXmlGHashMapAttrEntryPrivate));
		g_once_init_leave (&gxml_ghash_map_attr_entry_type_id__volatile, gxml_ghash_map_attr_entry_type_id);
	}
	return gxml_ghash_map_attr_entry_type_id__volatile;
}

static void
_vala_gxml_ghash_map_attr_entry_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec)
{
	GXmlGHashMapAttrEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_GHASH_MAP_ATTR_TYPE_ENTRY, GXmlGHashMapAttrEntry);
	switch (property_id) {
		case GXML_GHASH_MAP_ATTR_ENTRY_KEY_PROPERTY:
		g_value_set_string (value, gee_map_entry_get_key ((GeeMapEntry*) self));
		break;
		case GXML_GHASH_MAP_ATTR_ENTRY_READ_ONLY_PROPERTY:
		g_value_set_boolean (value, gee_map_entry_get_read_only ((GeeMapEntry*) self));
		break;
		case GXML_GHASH_MAP_ATTR_ENTRY_VALUE_PROPERTY:
		g_value_set_object (value, gee_map_entry_get_value ((GeeMapEntry*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gxml_ghash_map_attr_entry_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec)
{
	GXmlGHashMapAttrEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_GHASH_MAP_ATTR_TYPE_ENTRY, GXmlGHashMapAttrEntry);
	switch (property_id) {
		case GXML_GHASH_MAP_ATTR_ENTRY_VALUE_PROPERTY:
		gee_map_entry_set_value ((GeeMapEntry*) self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
gxml_ghash_map_attr_iterator_get_instance_private (GXmlGHashMapAttrIterator* self)
{
	return G_STRUCT_MEMBER_P (self, GXmlGHashMapAttrIterator_private_offset);
}

GXmlGHashMapAttrIterator*
gxml_ghash_map_attr_iterator_construct (GType object_type,
                                        GXmlGDocument* doc,
                                        xmlNode* node)
{
	GXmlGHashMapAttrIterator * self = NULL;
	GXmlGDocument* _tmp0_;
	g_return_val_if_fail (doc != NULL, NULL);
	self = (GXmlGHashMapAttrIterator*) g_object_new (object_type, NULL);
	self->priv->_node = node;
	self->priv->_current = NULL;
	_tmp0_ = _g_object_ref0 (doc);
	_g_object_unref0 (self->priv->_doc);
	self->priv->_doc = _tmp0_;
	return self;
}

GXmlGHashMapAttrIterator*
gxml_ghash_map_attr_iterator_new (GXmlGDocument* doc,
                                  xmlNode* node)
{
	return gxml_ghash_map_attr_iterator_construct (GXML_GHASH_MAP_ATTR_TYPE_ITERATOR, doc, node);
}

static gchar*
gxml_ghash_map_attr_iterator_real_get_key (GeeMapIterator* base)
{
	GXmlGHashMapAttrIterator * self;
	gchar* result = NULL;
	gchar* nullstr = NULL;
	xmlAttr* _tmp0_;
	self = (GXmlGHashMapAttrIterator*) base;
	nullstr = NULL;
	_tmp0_ = self->priv->_current;
	if (_tmp0_ != NULL) {
		xmlAttr* _tmp1_;
		const gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		_tmp1_ = self->priv->_current;
		_tmp2_ = _tmp1_->name;
		_tmp3_ = g_strdup (_tmp2_);
		_tmp4_ = _tmp3_;
		_g_free0 (_tmp4_);
	}
	result = nullstr;
	return result;
}

static GXmlGNode*
gxml_ghash_map_attr_iterator_real_get_value (GeeMapIterator* base)
{
	GXmlGHashMapAttrIterator * self;
	GXmlGNode* result = NULL;
	GXmlGDocument* _tmp0_;
	xmlAttr* _tmp1_;
	GXmlGAttribute* _tmp2_;
	self = (GXmlGHashMapAttrIterator*) base;
	_tmp0_ = self->priv->_doc;
	_tmp1_ = self->priv->_current;
	_tmp2_ = gxml_gattribute_new (_tmp0_, _tmp1_);
	result = (GXmlGNode*) _tmp2_;
	return result;
}

static gboolean
gxml_ghash_map_attr_iterator_real_has_next (GeeMapIterator* base)
{
	GXmlGHashMapAttrIterator * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_;
	xmlAttr* _tmp1_;
	xmlAttr* _tmp2_;
	self = (GXmlGHashMapAttrIterator*) base;
	_tmp0_ = self->priv->_node;
	_tmp1_ = _tmp0_->properties;
	if (_tmp1_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp2_ = self->priv->_current;
	if (_tmp2_ != NULL) {
		xmlAttr* _tmp3_;
		xmlAttr* _tmp4_;
		_tmp3_ = self->priv->_current;
		_tmp4_ = _tmp3_->next;
		if (_tmp4_ == NULL) {
			result = FALSE;
			return result;
		}
	}
	result = TRUE;
	return result;
}

static gboolean
gxml_ghash_map_attr_iterator_real_next (GeeMapIterator* base)
{
	GXmlGHashMapAttrIterator * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_;
	xmlAttr* _tmp1_;
	xmlAttr* _tmp2_;
	xmlAttr* _tmp5_;
	xmlAttr* _tmp6_;
	xmlAttr* _tmp7_;
	xmlAttr* _tmp8_;
	self = (GXmlGHashMapAttrIterator*) base;
	_tmp0_ = self->priv->_node;
	_tmp1_ = _tmp0_->properties;
	if (_tmp1_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp2_ = self->priv->_current;
	if (_tmp2_ == NULL) {
		xmlNode* _tmp3_;
		xmlAttr* _tmp4_;
		_tmp3_ = self->priv->_node;
		_tmp4_ = _tmp3_->properties;
		self->priv->_current = _tmp4_;
	}
	_tmp5_ = self->priv->_current;
	_tmp6_ = _tmp5_->next;
	if (_tmp6_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp7_ = self->priv->_current;
	_tmp8_ = _tmp7_->next;
	self->priv->_current = _tmp8_;
	result = TRUE;
	return result;
}

static void
gxml_ghash_map_attr_iterator_real_set_value (GeeMapIterator* base,
                                             GXmlGNode* value)
{
	GXmlGHashMapAttrIterator * self;
	xmlAttr* _tmp0_;
	xmlAttr* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gboolean _tmp6_;
	self = (GXmlGHashMapAttrIterator*) base;
	g_return_if_fail (value != NULL);
	_tmp0_ = self->priv->_current;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = self->priv->_current;
	_tmp2_ = _tmp1_->name;
	_tmp3_ = gxml_gnode_get_name (value);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	_tmp6_ = g_strcmp0 (_tmp2_, _tmp5_) == 0;
	_g_free0 (_tmp5_);
	if (_tmp6_) {
		xmlAttr* p = NULL;
		xmlNode* _tmp7_;
		xmlAttr* _tmp8_;
		_tmp7_ = self->priv->_node;
		_tmp8_ = _tmp7_->properties;
		p = _tmp8_;
		while (TRUE) {
			xmlAttr* _tmp9_;
			xmlAttr* _tmp10_;
			const gchar* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
			gchar* _tmp14_;
			gboolean _tmp15_;
			_tmp9_ = p;
			if (!(_tmp9_ != NULL)) {
				break;
			}
			_tmp10_ = p;
			_tmp11_ = _tmp10_->name;
			_tmp12_ = gxml_gnode_get_name (value);
			_tmp13_ = _tmp12_;
			_tmp14_ = _tmp13_;
			_tmp15_ = g_strcmp0 (_tmp11_, _tmp14_) == 0;
			_g_free0 (_tmp14_);
			if (_tmp15_) {
				xmlNode* _tmp16_;
				gchar* _tmp17_;
				gchar* _tmp18_;
				gchar* _tmp19_;
				gchar* _tmp20_;
				gchar* _tmp21_;
				gchar* _tmp22_;
				_tmp16_ = self->priv->_node;
				_tmp17_ = gxml_gnode_get_name (value);
				_tmp18_ = _tmp17_;
				_tmp19_ = _tmp18_;
				_tmp20_ = gxml_gnode_get_value (value);
				_tmp21_ = _tmp20_;
				_tmp22_ = _tmp21_;
				xmlSetProp (_tmp16_, (xmlChar*) _tmp19_, (xmlChar*) _tmp22_);
				_g_free0 (_tmp22_);
				_g_free0 (_tmp19_);
			}
		}
	}
}

static void
gxml_ghash_map_attr_iterator_real_unset (GeeMapIterator* base)
{
	GXmlGHashMapAttrIterator * self;
	xmlAttr* _tmp0_;
	xmlNode* _tmp1_;
	xmlAttr* _tmp2_;
	const gchar* _tmp3_;
	self = (GXmlGHashMapAttrIterator*) base;
	_tmp0_ = self->priv->_current;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = self->priv->_current;
	_tmp3_ = _tmp2_->name;
	xmlSetProp (_tmp1_, (xmlChar*) _tmp3_, (xmlChar*) NULL);
}

static gboolean
gxml_ghash_map_attr_iterator_real_get_mutable (GeeMapIterator* base)
{
	gboolean result;
	GXmlGHashMapAttrIterator* self;
	self = (GXmlGHashMapAttrIterator*) base;
	result = FALSE;
	return result;
}

static gboolean
gxml_ghash_map_attr_iterator_real_get_read_only (GeeMapIterator* base)
{
	gboolean result;
	GXmlGHashMapAttrIterator* self;
	self = (GXmlGHashMapAttrIterator*) base;
	result = FALSE;
	return result;
}

static gboolean
gxml_ghash_map_attr_iterator_real_get_valid (GeeMapIterator* base)
{
	gboolean result;
	GXmlGHashMapAttrIterator* self;
	xmlAttr* _tmp0_;
	self = (GXmlGHashMapAttrIterator*) base;
	_tmp0_ = self->priv->_current;
	result = _tmp0_ != NULL;
	return result;
}

static void
gxml_ghash_map_attr_iterator_class_init (GXmlGHashMapAttrIteratorClass * klass,
                                         gpointer klass_data)
{
	gxml_ghash_map_attr_iterator_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GXmlGHashMapAttrIterator_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_ghash_map_attr_iterator_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_ghash_map_attr_iterator_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GHASH_MAP_ATTR_ITERATOR_MUTABLE_PROPERTY, gxml_ghash_map_attr_iterator_properties[GXML_GHASH_MAP_ATTR_ITERATOR_MUTABLE_PROPERTY] = g_param_spec_boolean ("mutable", "mutable", "mutable", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GHASH_MAP_ATTR_ITERATOR_READ_ONLY_PROPERTY, gxml_ghash_map_attr_iterator_properties[GXML_GHASH_MAP_ATTR_ITERATOR_READ_ONLY_PROPERTY] = g_param_spec_boolean ("read-only", "read-only", "read-only", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GHASH_MAP_ATTR_ITERATOR_VALID_PROPERTY, gxml_ghash_map_attr_iterator_properties[GXML_GHASH_MAP_ATTR_ITERATOR_VALID_PROPERTY] = g_param_spec_boolean ("valid", "valid", "valid", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static GType
gxml_ghash_map_attr_iterator_gee_map_iterator_get_k_type (GXmlGHashMapAttrIterator* self)
{
	return G_TYPE_STRING;
}

static GBoxedCopyFunc
gxml_ghash_map_attr_iterator_gee_map_iterator_get_k_dup_func (GXmlGHashMapAttrIterator* self)
{
	return g_strdup;
}

static GDestroyNotify
gxml_ghash_map_attr_iterator_gee_map_iterator_get_k_destroy_func (GXmlGHashMapAttrIterator* self)
{
	return g_free;
}

static GType
gxml_ghash_map_attr_iterator_gee_map_iterator_get_v_type (GXmlGHashMapAttrIterator* self)
{
	return GXML_TYPE_GNODE;
}

static GBoxedCopyFunc
gxml_ghash_map_attr_iterator_gee_map_iterator_get_v_dup_func (GXmlGHashMapAttrIterator* self)
{
	return g_object_ref;
}

static GDestroyNotify
gxml_ghash_map_attr_iterator_gee_map_iterator_get_v_destroy_func (GXmlGHashMapAttrIterator* self)
{
	return g_object_unref;
}

static void
gxml_ghash_map_attr_iterator_gee_map_iterator_interface_init (GeeMapIteratorIface * iface,
                                                              gpointer iface_data)
{
	gxml_ghash_map_attr_iterator_gee_map_iterator_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_key = (gpointer (*) (GeeMapIterator*)) gxml_ghash_map_attr_iterator_real_get_key;
	iface->get_value = (gpointer (*) (GeeMapIterator*)) gxml_ghash_map_attr_iterator_real_get_value;
	iface->has_next = (gboolean (*) (GeeMapIterator*)) gxml_ghash_map_attr_iterator_real_has_next;
	iface->next = (gboolean (*) (GeeMapIterator*)) gxml_ghash_map_attr_iterator_real_next;
	iface->set_value = (void (*) (GeeMapIterator*, gconstpointer)) gxml_ghash_map_attr_iterator_real_set_value;
	iface->unset = (void (*) (GeeMapIterator*)) gxml_ghash_map_attr_iterator_real_unset;
	iface->get_k_type = (GType (*) (GeeMapIterator *)) gxml_ghash_map_attr_iterator_gee_map_iterator_get_k_type;
	iface->get_k_dup_func = (GBoxedCopyFunc (*) (GeeMapIterator *)) gxml_ghash_map_attr_iterator_gee_map_iterator_get_k_dup_func;
	iface->get_k_destroy_func = (GDestroyNotify (*) (GeeMapIterator *)) gxml_ghash_map_attr_iterator_gee_map_iterator_get_k_destroy_func;
	iface->get_v_type = (GType (*) (GeeMapIterator *)) gxml_ghash_map_attr_iterator_gee_map_iterator_get_v_type;
	iface->get_v_dup_func = (GBoxedCopyFunc (*) (GeeMapIterator *)) gxml_ghash_map_attr_iterator_gee_map_iterator_get_v_dup_func;
	iface->get_v_destroy_func = (GDestroyNotify (*) (GeeMapIterator *)) gxml_ghash_map_attr_iterator_gee_map_iterator_get_v_destroy_func;
	iface->get_mutable = gxml_ghash_map_attr_iterator_real_get_mutable;
	iface->get_read_only = gxml_ghash_map_attr_iterator_real_get_read_only;
	iface->get_valid = gxml_ghash_map_attr_iterator_real_get_valid;
}

static void
gxml_ghash_map_attr_iterator_instance_init (GXmlGHashMapAttrIterator * self,
                                            gpointer klass)
{
	self->priv = gxml_ghash_map_attr_iterator_get_instance_private (self);
}

static void
gxml_ghash_map_attr_iterator_finalize (GObject * obj)
{
	GXmlGHashMapAttrIterator * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_GHASH_MAP_ATTR_TYPE_ITERATOR, GXmlGHashMapAttrIterator);
	_g_object_unref0 (self->priv->_doc);
	G_OBJECT_CLASS (gxml_ghash_map_attr_iterator_parent_class)->finalize (obj);
}

GType
gxml_ghash_map_attr_iterator_get_type (void)
{
	static volatile gsize gxml_ghash_map_attr_iterator_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ghash_map_attr_iterator_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGHashMapAttrIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_ghash_map_attr_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGHashMapAttrIterator), 0, (GInstanceInitFunc) gxml_ghash_map_attr_iterator_instance_init, NULL };
		static const GInterfaceInfo gee_map_iterator_info = { (GInterfaceInitFunc) gxml_ghash_map_attr_iterator_gee_map_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_ghash_map_attr_iterator_type_id;
		gxml_ghash_map_attr_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlGHashMapAttrIterator", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_ghash_map_attr_iterator_type_id, GEE_TYPE_MAP_ITERATOR, &gee_map_iterator_info);
		GXmlGHashMapAttrIterator_private_offset = g_type_add_instance_private (gxml_ghash_map_attr_iterator_type_id, sizeof (GXmlGHashMapAttrIteratorPrivate));
		g_once_init_leave (&gxml_ghash_map_attr_iterator_type_id__volatile, gxml_ghash_map_attr_iterator_type_id);
	}
	return gxml_ghash_map_attr_iterator_type_id__volatile;
}

static void
_vala_gxml_ghash_map_attr_iterator_get_property (GObject * object,
                                                 guint property_id,
                                                 GValue * value,
                                                 GParamSpec * pspec)
{
	GXmlGHashMapAttrIterator * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_GHASH_MAP_ATTR_TYPE_ITERATOR, GXmlGHashMapAttrIterator);
	switch (property_id) {
		case GXML_GHASH_MAP_ATTR_ITERATOR_MUTABLE_PROPERTY:
		g_value_set_boolean (value, gee_map_iterator_get_mutable ((GeeMapIterator*) self));
		break;
		case GXML_GHASH_MAP_ATTR_ITERATOR_READ_ONLY_PROPERTY:
		g_value_set_boolean (value, gee_map_iterator_get_read_only ((GeeMapIterator*) self));
		break;
		case GXML_GHASH_MAP_ATTR_ITERATOR_VALID_PROPERTY:
		g_value_set_boolean (value, gee_map_iterator_get_valid ((GeeMapIterator*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
gxml_ghash_map_attr_class_init (GXmlGHashMapAttrClass * klass,
                                gpointer klass_data)
{
	gxml_ghash_map_attr_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GXmlGHashMapAttr_private_offset);
	((GeeAbstractMapClass *) klass)->clear = (void (*) (GeeAbstractMap*)) gxml_ghash_map_attr_real_clear;
	((GeeAbstractMapClass *) klass)->get = (gpointer (*) (GeeAbstractMap*, gconstpointer)) gxml_ghash_map_attr_real_get;
	((GeeAbstractMapClass *) klass)->has = (gboolean (*) (GeeAbstractMap*, gconstpointer, gconstpointer)) gxml_ghash_map_attr_real_has;
	((GeeAbstractMapClass *) klass)->has_key = (gboolean (*) (GeeAbstractMap*, gconstpointer)) gxml_ghash_map_attr_real_has_key;
	((GeeAbstractMapClass *) klass)->map_iterator = (GeeMapIterator* (*) (GeeAbstractMap*)) gxml_ghash_map_attr_real_map_iterator;
	((GeeAbstractMapClass *) klass)->set = (void (*) (GeeAbstractMap*, gconstpointer, gconstpointer)) gxml_ghash_map_attr_real_set;
	((GeeAbstractMapClass *) klass)->unset = (gboolean (*) (GeeAbstractMap*, gconstpointer, gpointer*)) gxml_ghash_map_attr_real_unset;
	GEE_ABSTRACT_MAP_CLASS (klass)->get_entries = gxml_ghash_map_attr_real_get_entries;
	GEE_ABSTRACT_MAP_CLASS (klass)->get_keys = gxml_ghash_map_attr_real_get_keys;
	GEE_ABSTRACT_MAP_CLASS (klass)->get_read_only = gxml_ghash_map_attr_real_get_read_only;
	GEE_ABSTRACT_MAP_CLASS (klass)->get_size = gxml_ghash_map_attr_real_get_size;
	GEE_ABSTRACT_MAP_CLASS (klass)->get_values = gxml_ghash_map_attr_real_get_values;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_ghash_map_attr_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_ghash_map_attr_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GHASH_MAP_ATTR_ENTRIES_PROPERTY, gxml_ghash_map_attr_properties[GXML_GHASH_MAP_ATTR_ENTRIES_PROPERTY] = g_param_spec_object ("entries", "entries", "entries", GEE_TYPE_SET, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GHASH_MAP_ATTR_KEYS_PROPERTY, gxml_ghash_map_attr_properties[GXML_GHASH_MAP_ATTR_KEYS_PROPERTY] = g_param_spec_object ("keys", "keys", "keys", GEE_TYPE_SET, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GHASH_MAP_ATTR_READ_ONLY_PROPERTY, gxml_ghash_map_attr_properties[GXML_GHASH_MAP_ATTR_READ_ONLY_PROPERTY] = g_param_spec_boolean ("read-only", "read-only", "read-only", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GHASH_MAP_ATTR_SIZE_PROPERTY, gxml_ghash_map_attr_properties[GXML_GHASH_MAP_ATTR_SIZE_PROPERTY] = g_param_spec_int ("size", "size", "size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GHASH_MAP_ATTR_VALUES_PROPERTY, gxml_ghash_map_attr_properties[GXML_GHASH_MAP_ATTR_VALUES_PROPERTY] = g_param_spec_object ("values", "values", "values", GEE_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GHASH_MAP_ATTR_LENGTH_PROPERTY, gxml_ghash_map_attr_properties[GXML_GHASH_MAP_ATTR_LENGTH_PROPERTY] = g_param_spec_int ("length", "length", "length", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
gxml_ghash_map_attr_gxml_dom_named_node_map_interface_init (GXmlDomNamedNodeMapIface * iface,
                                                            gpointer iface_data)
{
	gxml_ghash_map_attr_gxml_dom_named_node_map_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_named_item = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, const gchar*)) gxml_ghash_map_attr_real_get_named_item;
	iface->item = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, gint)) gxml_ghash_map_attr_real_item;
	iface->set_named_item = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, GXmlDomNode*, GError**)) gxml_ghash_map_attr_real_set_named_item;
	iface->remove_named_item = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, const gchar*, GError**)) gxml_ghash_map_attr_real_remove_named_item;
	iface->get_named_item_ns = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, const gchar*, const gchar*, GError**)) gxml_ghash_map_attr_real_get_named_item_ns;
	iface->set_named_item_ns = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, GXmlDomNode*, GError**)) gxml_ghash_map_attr_real_set_named_item_ns;
	iface->remove_named_item_ns = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, const gchar*, const gchar*, GError**)) gxml_ghash_map_attr_real_remove_named_item_ns;
	iface->get_length = gxml_ghash_map_attr_real_get_length;
}

static void
gxml_ghash_map_attr_instance_init (GXmlGHashMapAttr * self,
                                   gpointer klass)
{
	self->priv = gxml_ghash_map_attr_get_instance_private (self);
}

static void
gxml_ghash_map_attr_finalize (GObject * obj)
{
	GXmlGHashMapAttr * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GHASH_MAP_ATTR, GXmlGHashMapAttr);
	_g_object_unref0 (self->priv->_doc);
	G_OBJECT_CLASS (gxml_ghash_map_attr_parent_class)->finalize (obj);
}

/**
 * Implementation of {@link Gee.AbstractMap} to handle {@link Xml.Node} attributes,
 * powered by libxml2 library.
 */
GType
gxml_ghash_map_attr_get_type (void)
{
	static volatile gsize gxml_ghash_map_attr_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ghash_map_attr_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGHashMapAttrClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_ghash_map_attr_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGHashMapAttr), 0, (GInstanceInitFunc) gxml_ghash_map_attr_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_named_node_map_info = { (GInterfaceInitFunc) gxml_ghash_map_attr_gxml_dom_named_node_map_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_ghash_map_attr_type_id;
		gxml_ghash_map_attr_type_id = g_type_register_static (GEE_TYPE_ABSTRACT_MAP, "GXmlGHashMapAttr", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_ghash_map_attr_type_id, GXML_TYPE_DOM_NAMED_NODE_MAP, &gxml_dom_named_node_map_info);
		GXmlGHashMapAttr_private_offset = g_type_add_instance_private (gxml_ghash_map_attr_type_id, sizeof (GXmlGHashMapAttrPrivate));
		g_once_init_leave (&gxml_ghash_map_attr_type_id__volatile, gxml_ghash_map_attr_type_id);
	}
	return gxml_ghash_map_attr_type_id__volatile;
}

static void
_vala_gxml_ghash_map_attr_get_property (GObject * object,
                                        guint property_id,
                                        GValue * value,
                                        GParamSpec * pspec)
{
	GXmlGHashMapAttr * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GHASH_MAP_ATTR, GXmlGHashMapAttr);
	switch (property_id) {
		case GXML_GHASH_MAP_ATTR_ENTRIES_PROPERTY:
		g_value_take_object (value, gee_abstract_map_get_entries ((GeeAbstractMap*) self));
		break;
		case GXML_GHASH_MAP_ATTR_KEYS_PROPERTY:
		g_value_take_object (value, gee_abstract_map_get_keys ((GeeAbstractMap*) self));
		break;
		case GXML_GHASH_MAP_ATTR_READ_ONLY_PROPERTY:
		g_value_set_boolean (value, gee_abstract_map_get_read_only ((GeeAbstractMap*) self));
		break;
		case GXML_GHASH_MAP_ATTR_SIZE_PROPERTY:
		g_value_set_int (value, gee_abstract_map_get_size ((GeeAbstractMap*) self));
		break;
		case GXML_GHASH_MAP_ATTR_VALUES_PROPERTY:
		g_value_take_object (value, gee_abstract_map_get_values ((GeeAbstractMap*) self));
		break;
		case GXML_GHASH_MAP_ATTR_LENGTH_PROPERTY:
		g_value_set_int (value, gxml_dom_named_node_map_get_length ((GXmlDomNamedNodeMap*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}

